@@ -24,10 +24,15 @@
  *                                                                           *
  *****************************************************************************/
 
-#include "charts/statscqzperyearbarchartwidget.h"
+#include "statscqzperyearbarchartwidget.h"
 
 
-StatsCQZPerYearBarChartWidget::StatsCQZPerYearBarChartWidget(){}
+StatsCQZPerYearBarChartWidget::StatsCQZPerYearBarChartWidget()
+{
+    dataProxy = new DataProxy_SQLite(Q_FUNC_INFO);
+    chart = new QChart();
+    chartView = new QChartView(chart);
+}
 
 StatsCQZPerYearBarChartWidget::StatsCQZPerYearBarChartWidget(DataProxy_SQLite *dp, QWidget *parent)
 {
@@ -53,6 +58,11 @@ void StatsCQZPerYearBarChartWidget::createUI()
     setLayout(graphLayout);
 }
 
+StatsCQZPerYearBarChartWidget::~StatsCQZPerYearBarChartWidget()
+{
+    delete(dataProxy);
+}
+
 void StatsCQZPerYearBarChartWidget::prepareChart(const int _log)
 {
 
