@@ -31,8 +31,8 @@
 #include <QtWidgets>
 #include <QtCharts>
 #include <QtDebug>
-#include "dataproxy_sqlite.h"
-#include "charts/statsgeneralchartwidget.h"
+#include "../dataproxy_sqlite.h"
+#include "statsgeneralchartwidget.h"
 
 
 
@@ -42,6 +42,7 @@ class StatsCQZPerYearBarChartWidget : public StatsGeneralChartWidget
 public:
     StatsCQZPerYearBarChartWidget(DataProxy_SQLite *dp, QWidget *parent = nullptr);
     StatsCQZPerYearBarChartWidget();
+    ~StatsCQZPerYearBarChartWidget();
     void prepareChart(const int _log=-1);
 
 
