@@ -31,10 +31,10 @@
 #include <QtCharts>
 #include <QtDebug>
 #include <QTableWidget>
-#include "dataproxy_sqlite.h"
-#include "qso.h"
-#include "utilities.h"
-#include "charts/statsgeneralchartwidget.h"
+#include "../dataproxy_sqlite.h"
+#include "../qso.h"
+#include "../utilities.h"
+#include "../charts/statsgeneralchartwidget.h"
 
 class StatsDXCCOnSatsWidget : public StatsGeneralChartWidget
 {
