@@ -23,10 +23,15 @@
  *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.         *
  *                                                                           *
  *****************************************************************************/
-#include "charts/statsentitiesperyearbarchartwidget.h"
+#include "statsentitiesperyearbarchartwidget.h"
 
 
-StatsEntitiesPerYearBarChartWidget::StatsEntitiesPerYearBarChartWidget(){}
+StatsEntitiesPerYearBarChartWidget::StatsEntitiesPerYearBarChartWidget()
+{
+    dataProxy = new DataProxy_SQLite(Q_FUNC_INFO);
+    chart = new QChart();
+    chartView = new QChartView(chart);
+}
 
 StatsEntitiesPerYearBarChartWidget::StatsEntitiesPerYearBarChartWidget(DataProxy_SQLite *dp, QWidget *parent)
 {
@@ -44,6 +49,11 @@ StatsEntitiesPerYearBarChartWidget::StatsEntitiesPerYearBarChartWidget(DataProxy
     //prepareChart();
 }
 
+StatsEntitiesPerYearBarChartWidget::~StatsEntitiesPerYearBarChartWidget()
+{
+    delete(dataProxy);
+}
+
 void StatsEntitiesPerYearBarChartWidget::createUI()
 {
     chart->setAnimationOptions(QChart::SeriesAnimations);
@@ -66,10 +76,10 @@ void StatsEntitiesPerYearBarChartWidget::prepareChart(const int _log)
     QBarCategoryAxis *axis = new QBarCategoryAxis();
     QString aux;
 
-    int numberPerX = 0;
+    //int numberPerX = 0;
     chart->removeAllSeries();
-    categoriesTitle = QString();
-    categoriesElem = QString();
+    categoriesTitle = tr("DXCC Entities");
+    categoriesElem = tr("DXCC Entities");
     categories.clear();
     axis->clear();
     series->clear();
@@ -83,9 +93,10 @@ void StatsEntitiesPerYearBarChartWidget::prepareChart(const int _log)
        //qDebug() << "StatsEntitiesPerYearBarChartWidget::prepareChart: SelectedGrapth-1: YEARS " << QT_ENDL;
        //qDebug() << "BarChartStats::prepareChart: SelectedGrapth-2: DXCC " << QT_ENDL;
         categories.append(dataProxy->getOperatingYears(_log));
-        categoriesElem = tr("DXCC Entities");
-        categoriesTitle = tr("DXCC Entities per year");
+        //categoriesElem = tr("DXCC Entities");
+        //categoriesTitle = tr("DXCC Entities");
         aux.clear();
+        int numberPerX;
         for (int i = 0; i < categories.count();i++ )
         {
             numberPerX = dataProxy->getDXCConYear((categories.at(i)).toInt(), _log);
