@@ -31,8 +31,8 @@
 #include <QtWidgets>
 #include <QtCharts>
 #include <QtDebug>
-#include "dataproxy_sqlite.h"
-#include "charts/statsgeneralchartwidget.h"
+#include "../dataproxy_sqlite.h"
+#include "../charts/statsgeneralchartwidget.h"
 
 
 class StatsEntitiesPerYearBarChartWidget : public StatsGeneralChartWidget
@@ -41,6 +41,7 @@ class StatsEntitiesPerYearBarChartWidget : public StatsGeneralChartWidget
 public:
     StatsEntitiesPerYearBarChartWidget(DataProxy_SQLite *dp, QWidget *parent = nullptr);
     StatsEntitiesPerYearBarChartWidget();
+    ~StatsEntitiesPerYearBarChartWidget();
     void prepareChart(const int _log=-1);
 
 signals:
