@@ -24,7 +24,7 @@
  *                                                                           *
  *****************************************************************************/
 
-#include "charts/statsgeneralchartwidget.h"
+#include "statsgeneralchartwidget.h"
 
 
 StatsGeneralChartWidget::StatsGeneralChartWidget()
