@@ -28,7 +28,7 @@
 #include <QWidget>
 #include <QtWidgets>
 #include <QtDebug>
-#include "dataproxy_sqlite.h"
+#include "../dataproxy_sqlite.h"
 
 class StatsGeneralChartWidget : public QWidget
 {
