@@ -24,10 +24,14 @@
  *                                                                           *
  *****************************************************************************/
 
-#include "charts/statsqsosperbandbarchartwidget.h"
+#include "statsqsosperbandbarchartwidget.h"
 
-
-StatsQSOsPerBandBarChartWidget::StatsQSOsPerBandBarChartWidget(){}
+StatsQSOsPerBandBarChartWidget::StatsQSOsPerBandBarChartWidget()
+{
+    dataProxy = new DataProxy_SQLite(Q_FUNC_INFO);
+    chart = new QChart();
+    chartView = new QChartView(chart);
+}
 
 StatsQSOsPerBandBarChartWidget::StatsQSOsPerBandBarChartWidget(DataProxy_SQLite *dp, QWidget *parent)
 {
@@ -41,6 +45,11 @@ StatsQSOsPerBandBarChartWidget::StatsQSOsPerBandBarChartWidget(DataProxy_SQLite
     //prepareChart();
 }
 
+StatsQSOsPerBandBarChartWidget::~StatsQSOsPerBandBarChartWidget()
+{
+    delete(dataProxy);
+}
+
 void StatsQSOsPerBandBarChartWidget::createUI()
 {
     chart->setAnimationOptions(QChart::SeriesAnimations);
