@@ -23,14 +23,12 @@
  *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.         *
  *                                                                           *
  *****************************************************************************/
-#include "charts/statsqsospercontinentbarchartwidget.h"
+#include "statsqsospercontinentbarchartwidget.h"
 
 
-StatsQSOsPerContinentBarChartWidget::StatsQSOsPerContinentBarChartWidget(){}
-
 StatsQSOsPerContinentBarChartWidget::StatsQSOsPerContinentBarChartWidget(DataProxy_SQLite *dp, QWidget *parent)
 {
-      //qDebug() << "StatsQSOsPerContinentBarChartWidget::StatsQSOsPerContinentBarChartWidget" << endl;
+      //qDebug() << "StatsQSOsPerContinentBarChartWidget::StatsQSOsPerContinentBarChartWidget" << QT_ENDL;
 
     dataProxy = dp;
     chart = new QChart();
@@ -40,6 +38,18 @@ StatsQSOsPerContinentBarChartWidget::StatsQSOsPerContinentBarChartWidget(DataPro
     //prepareChart();
 }
 
+StatsQSOsPerContinentBarChartWidget::StatsQSOsPerContinentBarChartWidget()
+{
+    dataProxy = new DataProxy_SQLite(Q_FUNC_INFO);
+    chart = new QChart();
+    chartView = new QChartView(chart);
+}
+
+StatsQSOsPerContinentBarChartWidget::~StatsQSOsPerContinentBarChartWidget()
+{
+    delete(dataProxy);
+}
+
 void StatsQSOsPerContinentBarChartWidget::createUI()
 {
     chart->setAnimationOptions(QChart::SeriesAnimations);
@@ -88,9 +98,9 @@ void StatsQSOsPerContinentBarChartWidget::prepareChart(const int _log)
      for (int i = 0; i < categories.count(); i++ )
      {
          numberPerX = dataProxy->getQSOsWithContinent(categories.at(i), _log);
-            //qDebug() << "BarChartStats::prepareChart SelectedGrapth-7: QSO/hour: " << categories.at(i) << " - " << QString::number(numberPerX) << endl;
+            //qDebug() << "BarChartStats::prepareChart SelectedGrapth-7: QSO/hour: " << categories.at(i) << " - " << QString::number(numberPerX) << QT_ENDL;
          *set0 << numberPerX;
-         numberPerX = 0;
+         //numberPerX = 0;
 
          aux = tr("Reading data ...") + "\n" + tr("Hours: ")  + QString::number(i) + "/" + QString::number(categories.count());
          progress.setLabelText(aux);
@@ -100,7 +110,7 @@ void StatsQSOsPerContinentBarChartWidget::prepareChart(const int _log)
          {
              i = categories.count();
          }
-            //qDebug() << "BarChartStats::prepareChart CQz: " << QString::number((categories.at(i)).toInt()) << "/" << QString::number(numberPerX) << endl;
+            //qDebug() << "BarChartStats::prepareChart CQz: " << QString::number((categories.at(i)).toInt()) << "/" << QString::number(numberPerX) << QT_ENDL;
      }
 
     sum = set0->sum();
