@@ -24,10 +24,15 @@
  *                                                                           *
  *****************************************************************************/
 
-#include "charts/statsqsosperdxccbarchartwidget.h"
+#include "statsqsosperdxccbarchartwidget.h"
 
 
-StatsQSOsPerDXCCBarChartWidget::StatsQSOsPerDXCCBarChartWidget(){}
+StatsQSOsPerDXCCBarChartWidget::StatsQSOsPerDXCCBarChartWidget()
+{
+    dataProxy = new DataProxy_SQLite(Q_FUNC_INFO);
+    chart = new QChart();
+    chartView = new QChartView(chart);
+}
 
 StatsQSOsPerDXCCBarChartWidget::StatsQSOsPerDXCCBarChartWidget(DataProxy_SQLite *dp, QWidget *parent)
 {
@@ -45,6 +50,11 @@ StatsQSOsPerDXCCBarChartWidget::StatsQSOsPerDXCCBarChartWidget(DataProxy_SQLite
    // prepareChart();
 }
 
+StatsQSOsPerDXCCBarChartWidget::~StatsQSOsPerDXCCBarChartWidget()
+{
+    delete(dataProxy);
+}
+
 void StatsQSOsPerDXCCBarChartWidget::createUI()
 {
     chart->setAnimationOptions(QChart::SeriesAnimations);
