@@ -24,10 +24,15 @@
  *                                                                           *
  *****************************************************************************/
 
-#include "charts/statsqsosperhourbarchartwidget.h"
+#include "statsqsosperhourbarchartwidget.h"
 
 
-StatsQSOsPerHourBarChartWidget::StatsQSOsPerHourBarChartWidget(){}
+StatsQSOsPerHourBarChartWidget::StatsQSOsPerHourBarChartWidget()
+{
+    dataProxy = new DataProxy_SQLite(Q_FUNC_INFO);
+    chart = new QChart();
+    chartView = new QChartView(chart);
+}
 
 StatsQSOsPerHourBarChartWidget::StatsQSOsPerHourBarChartWidget(DataProxy_SQLite *dp, QWidget *parent)
 {
@@ -43,6 +48,10 @@ StatsQSOsPerHourBarChartWidget::StatsQSOsPerHourBarChartWidget(DataProxy_SQLite
     createUI();
     //prepareChart();
 }
+StatsQSOsPerHourBarChartWidget::~StatsQSOsPerHourBarChartWidget()
+{
+    delete(dataProxy);
+}
 
 void StatsQSOsPerHourBarChartWidget::createUI()
 {
