@@ -24,10 +24,15 @@
  *                                                                           *
  *****************************************************************************/
 
-#include "charts/statsqsospermodebarchartwidget.h"
+#include "statsqsospermodebarchartwidget.h"
 
 
-StatsQSOsPerModeBarChartWidget::StatsQSOsPerModeBarChartWidget(){}
+StatsQSOsPerModeBarChartWidget::StatsQSOsPerModeBarChartWidget()
+{
+    dataProxy = new DataProxy_SQLite(Q_FUNC_INFO);
+    chart = new QChart();
+    chartView = new QChartView(chart);
+}
 
 StatsQSOsPerModeBarChartWidget::StatsQSOsPerModeBarChartWidget(DataProxy_SQLite *dp, QWidget *parent)
 {
@@ -45,6 +50,11 @@ StatsQSOsPerModeBarChartWidget::StatsQSOsPerModeBarChartWidget(DataProxy_SQLite
     //prepareChart();
 }
 
+StatsQSOsPerModeBarChartWidget::~StatsQSOsPerModeBarChartWidget()
+{
+    delete(dataProxy);
+}
+
 void StatsQSOsPerModeBarChartWidget::createUI()
 {
     chart->setAnimationOptions(QChart::SeriesAnimations);
