@@ -24,10 +24,15 @@
  *                                                                           *
  *****************************************************************************/
 
-#include "charts/statsqsosperyearbarchartwidget.h"
+#include "statsqsosperyearbarchartwidget.h"
 
 
-StatsQSOsPerYearBarChartWidget::StatsQSOsPerYearBarChartWidget(){}
+StatsQSOsPerYearBarChartWidget::StatsQSOsPerYearBarChartWidget()
+{
+    dataProxy = new DataProxy_SQLite(Q_FUNC_INFO);
+    chart = new QChart();
+    chartView = new QChartView(chart);
+}
 
 StatsQSOsPerYearBarChartWidget::StatsQSOsPerYearBarChartWidget(DataProxy_SQLite *dp, QWidget *parent)
 {
@@ -41,6 +46,11 @@ StatsQSOsPerYearBarChartWidget::StatsQSOsPerYearBarChartWidget(DataProxy_SQLite
     //prepareChart();
 }
 
+StatsQSOsPerYearBarChartWidget::~StatsQSOsPerYearBarChartWidget()
+{
+    delete(dataProxy);
+}
+
 void StatsQSOsPerYearBarChartWidget::createUI()
 {
     chart->setAnimationOptions(QChart::SeriesAnimations);
