@@ -24,9 +24,14 @@
  *                                                                           *
  *****************************************************************************/
 
-#include "charts/statssentconfirmedpiechartwidget.h"
+#include "statssentconfirmedpiechartwidget.h"
 
-StatsSentConfirmedPieChartWidget::StatsSentConfirmedPieChartWidget(){}
+StatsSentConfirmedPieChartWidget::StatsSentConfirmedPieChartWidget()
+{
+    dataProxy = new DataProxy_SQLite(Q_FUNC_INFO);
+    chart = new QChart();
+    chartView = new QChartView(chart);
+}
 
 StatsSentConfirmedPieChartWidget::StatsSentConfirmedPieChartWidget(DataProxy_SQLite *dp, QWidget *parent)
 {
@@ -40,6 +45,11 @@ StatsSentConfirmedPieChartWidget::StatsSentConfirmedPieChartWidget(DataProxy_SQL
     //prepareChart();
 }
 
+StatsSentConfirmedPieChartWidget::~StatsSentConfirmedPieChartWidget()
+{
+    delete(dataProxy);
+}
+
 void StatsSentConfirmedPieChartWidget::createUI()
 {
     chart->setAnimationOptions(QChart::SeriesAnimations);
