@@ -24,9 +24,14 @@
  *                                                                           *
  *****************************************************************************/
 
-#include "charts/statsworkedconfirmedpiechartwidget.h"
+#include "statsworkedconfirmedpiechartwidget.h"
 
-StatsWorkedConfirmedPieChartWidget::StatsWorkedConfirmedPieChartWidget(){}
+StatsWorkedConfirmedPieChartWidget::StatsWorkedConfirmedPieChartWidget()
+{
+    dataProxy = new DataProxy_SQLite(Q_FUNC_INFO);
+    chart = new QChart();
+    chartView = new QChartView(chart);
+}
 
 StatsWorkedConfirmedPieChartWidget::StatsWorkedConfirmedPieChartWidget(DataProxy_SQLite *dp, QWidget *parent)
 {
@@ -35,8 +40,6 @@ StatsWorkedConfirmedPieChartWidget::StatsWorkedConfirmedPieChartWidget(DataProxy
       //qDebug() << "StatsWorkedConfirmedPieChartWidget::StatsWorkedConfirmedPieChartWidget" << QT_ENDL;
 #else
 #endif
-
-
     dataProxy = dp;
     chart = new QChart();
     chartView = new QChartView(chart);
@@ -45,6 +48,11 @@ StatsWorkedConfirmedPieChartWidget::StatsWorkedConfirmedPieChartWidget(DataProxy
     //prepareChart();
 }
 
+StatsWorkedConfirmedPieChartWidget::~StatsWorkedConfirmedPieChartWidget()
+{
+    delete(dataProxy);
+}
+
 void StatsWorkedConfirmedPieChartWidget::createUI()
 {
     chart->setAnimationOptions(QChart::SeriesAnimations);
