@@ -24,9 +24,14 @@
  *                                                                           *
  *****************************************************************************/
 
-#include "charts/statsworkedsentpiechartwidget.h"
+#include "statsworkedsentpiechartwidget.h"
 
-StatsWorkedSentPieChartWidget::StatsWorkedSentPieChartWidget(){}
+StatsWorkedSentPieChartWidget::StatsWorkedSentPieChartWidget()
+{
+    dataProxy = new DataProxy_SQLite(Q_FUNC_INFO);
+    chart = new QChart();
+    chartView = new QChartView(chart);
+}
 
 StatsWorkedSentPieChartWidget::StatsWorkedSentPieChartWidget(DataProxy_SQLite *dp, QWidget *parent)
 {
@@ -40,6 +45,11 @@ StatsWorkedSentPieChartWidget::StatsWorkedSentPieChartWidget(DataProxy_SQLite *d
     //prepareChart();
 }
 
+StatsWorkedSentPieChartWidget::~StatsWorkedSentPieChartWidget()
+{
+    delete(dataProxy);
+}
+
 void StatsWorkedSentPieChartWidget::createUI()
 {
     chart->setAnimationOptions(QChart::SeriesAnimations);
