@@ -31,8 +31,8 @@
 #include <QtWidgets>
 #include <QtCharts>
 #include <QtDebug>
-#include "dataproxy_sqlite.h"
-#include "charts/statsgeneralchartwidget.h"
+#include "../dataproxy_sqlite.h"
+#include "../charts/statsgeneralchartwidget.h"
 
 
 
@@ -42,6 +42,7 @@ class StatsWorkedSentPieChartWidget : public StatsGeneralChartWidget
 public:
     StatsWorkedSentPieChartWidget(DataProxy_SQLite *dp, QWidget *parent = nullptr);
     StatsWorkedSentPieChartWidget();
+    ~StatsWorkedSentPieChartWidget();
     void prepareChart(const int _log=-1);
 
 signals:
