@@ -40,7 +40,7 @@
 #include "utilities.h"
 
 class QSqlRelationalTableModel;
-const float DBVersionf = 0.023f; // This is the latest version of the DB.
+const float DBVersionf = 0.025f; // This is the latest version of the DB.
 
 
 struct AwarddxccEntry
@@ -62,9 +62,9 @@ struct AwarddxccEntryCheck
     QString logNumber;
 };
 
-class DataBase //: public QObject
+class DataBase : public QObject
 {
-   // Q_OBJECT
+    Q_OBJECT
 
 public:
     DataBase(const QString &_parentClass, const QString &_DBName);
@@ -128,7 +128,7 @@ public:
     bool updateAwardDXCCTable();
     bool updateAwardWAZTable();
     int getNumberOfQsos(const int _logNumber);
-
+    void setLogLevel (const DebugLogLevel _b);
 //private slots:
 //    void slotPrintErrors(QString _func, QString _msg, int _level);
 
@@ -164,6 +164,8 @@ private:
     bool updateTo021(); // Adds 5M & 8M bands
     bool updateTo022(); // Recovers the 020 that was not executed and adds the Q65 mode
     bool updateTo023(); // Fixes the cabrillo fields in the table band
+    bool updateTo024(); // Fixes the entity table fixinf the DL id
+    bool updateTo025(); // Adds modes from ADIF 3.1.3
 
     bool updateTableLog(const int _v);
     bool updateDBVersion(QString _softV, QString _dbV);
@@ -227,9 +229,9 @@ private:
     bool updateModeIdTableAward(const int _db);
 
     void queryErrorManagement(const QString &_functionFailed, const QString &errorCodeS, const QString &_nativeError, const QString &_failedQuery);
+    void logEvent(const QString &_func, const QString &_msg, DebugLogLevel _level);
 
-
-
+    DebugLogLevel logLevel;
     bool created;
     float dbVersion;    // The current version of the DB. May differ from latestReaded if we are updating the DB!
     QString dbConnectionName;
@@ -258,9 +260,9 @@ private:
 
     int constrid; // Just an id for the constructor to check who is being executed at one specific time
 
-//signals:
+signals:
     //void queryError(QString functionFailed, QString errorCodeS, QString nativeError, QString failedQuery); // To alert about any failed query execution
-    //void debugLog(QString functionFailed, QString errorCode, int level); // emitted when a function retuns false due to an error
+    void debugLog (QString _func, QString _msg, DebugLogLevel _level);
 
 
 };
