@@ -31,10 +31,11 @@
 #include <QObject>
 #include "database.h"
 #include "qso.h"
+#include "utilities.h"
 #include "klogdefinitions.h"
 //#include "regionalaward.h"
 
-//Class QSO;
+class QSO;
 
 enum
 {
@@ -51,7 +52,7 @@ public:
 
     DataProxy_SQLite(const QString &_parentFunction, const QString &_softVersion="0.0");
     ~DataProxy_SQLite();
-
+    void setLogLevel (const DebugLogLevel _l);
     QString getSoftVersion();
     QString getDBVersion();
     bool reconnectDB();
@@ -178,7 +179,7 @@ public:
     bool lotwSentYes(const QDate &_updateDate, const int _currentLog, const QString &_station);         // Update LOTW QSL SENT marked as Q as Y (Queued)
     bool lotwSentQSOs(const QList<int> &_qsos);
     int lotwUpdateQSLReception (const QString &_call, const QDateTime &_dateTime, const QString &_band, const QString &_mode, const QDate &_qslrdate);
-    QList<int> getQSOsListLoTWToSend(const QString &_stationCallsign, const QDate &_startDate, const QDate &_endDate, bool _justQueued=true, int _logN = -1);
+    QList<int> getQSOsListLoTWToSend(const QString &_stationCallsign, const QString &_myGrid, const QDate &_startDate, const QDate &_endDate, bool _justQueued=true, int _logN = -1);
     //QStringList getQSOsListLoTWNotSent2(const QString &_stationCallsign, const QDate &_startDate, const QDate &_endDate, bool _justQueued=true);
     QStringList getQSODetailsForLoTWDownload(const int _id);
 
@@ -188,6 +189,8 @@ public:
     QList<int> getQSOsListEQSLToSent(const QString &_stationCallsign, const QDate &_startDate, const QDate &_endDate, bool _justModified=true);
     QList<int> getQSOsListQRZCOMToSent(const QString &_stationCallsign, const QDate &_startDate, const QDate &_endDate, bool _justModified=true);
     QList<int> getQSOsListToBeExported(const QString &_stationCallsign, const QDate &_startDate, const QDate &_endDate);
+    QStringList getGridsToBeSent(const QString &_stationCallsign, const QDate &_startDate, const QDate &_endDate, bool _justModified=true, int _logN = -1);
+
 
     int getContinentIdFromContinentShortName(const QString &_n);
     QString getContinentShortNameFromEntity(const int _n);
@@ -212,6 +215,9 @@ public:
     double getLatitudeFromEntity(const int _e);
     int getDXCCFromPrefix(const QString &_p);
     QString getEntityPrefixes(const int _enti);
+    QStringList getLongPrefixes();
+    QStringList getSpecialCallsigns();
+    QHash<QString, int> getWorldData();
     QStringList getEntitiesNames();
     QStringList getEntitiesIds();
     int getHowManyEntities();
@@ -291,6 +297,7 @@ public:
     int getMaxLogNumber();
     QString getStationCallSignFromLog(const int _log);
     QStringList getStationCallSignsFromLog(const int _log);
+    QStringList getStationCallSignsFromLogWithLoTWPendingToSend(const int _log);
     QString getOperatorsFromLog(const int _log);
     QString getCommentsFromLog(const int _log);
     QString getLogDateFromLog(const int _log);
@@ -327,20 +334,21 @@ private:
     QStringList getColumnNamesFromTable(const QString &_tableName);
 
     int getPrefixId(const QString &_qrz);
-    QString changeSlashAndFindPrefix(const QString &_qrz);
+    //QString changeSlashAndFindPrefix(const QString &_qrz);
+    void logEvent(const QString &_func, const QString &_msg, DebugLogLevel _level);
     QSO *qso;
     bool searching;
     int executionN;
     Utilities *util;
+    DebugLogLevel logLevel;
     //QSqlQuery preparedQuery;
     //QSqlRelationalTableModel *logModel;
 private slots:
-    void slotCaptureDebugLogs(const QString &_func, const QString &_msg, const DebugLogLevel _level=Info);
-
+    void slotCaptureDebugLogs(const QString &_func, const QString &_msg, DebugLogLevel _l);
 signals:
     void qsoFound(const QStringList _qs); // Each: QString with format: Fieldname:value
     void queryError(QString functionFailed, QString errorCodeS, QString nativeError, QString failedQuery); // To alert about any failed query execution
-    void debugLog(QString functionFailed, QString errorCode, DebugLogLevel level); // emitted as the KLog application log
+    void debugLog (QString _func, QString _msg, DebugLogLevel _level);
 
 };
 
