@@ -25,7 +25,7 @@ email                : jaime@robles.es
 *****************************************************************************/
 #include <QFont>
 #include "dxcluster.h"
-
+/*
 DXClusterWidget::DXClusterWidget(DataProxy_SQLite *dp, QWidget *parent)
           : QWidget(parent)
 {
@@ -33,37 +33,29 @@ DXClusterWidget::DXClusterWidget(DataProxy_SQLite *dp, QWidget *parent)
     dataProxy = dp;
     constrid = 1;
     awards = new Awards(dataProxy, Q_FUNC_INFO);
-    util = new Utilities;
+    util = new Utilities(Q_FUNC_INFO);
     saveSpotsFile = new QFile();
-
-
-    initClass();
+    //initClass();
        //qDebug() << "DXClusterWidget::DXClusterWidget - END" << QT_ENDL;
 }
-
-DXClusterWidget::DXClusterWidget(DataProxy_SQLite *dp, const QString &clusterToConnect, const int portToConnect, QWidget *parent)
+*/
+DXClusterWidget::DXClusterWidget(DataProxy_SQLite *dp, QWidget *parent)
           : QWidget(parent)
+//DXClusterWidget::DXClusterWidget(DataProxy_SQLite *dp, const QString &clusterToConnect, const int portToConnect, QWidget *parent)
+//          : QWidget(parent)
 {
       //qDebug() << "DXClusterWidget::DXClusterWidget2" << clusterToConnect << QString::number(portToConnect) << QT_ENDL;
-   constrid = 2;
-   util = new Utilities;
-   saveSpotsFile = new QFile();
 
-    initClass();
-    server = clusterToConnect;
-    port = quint16(portToConnect);
 
-    dxSpotColor.setNamedColor("slategrey");
-    //defaultColor.setNamedColor("slategrey");
-    //neededColor.setNamedColor("slategrey");
-    //workedColor.setNamedColor("slategrey");
-    //confirmedColor.setNamedColor("slategrey");
-    //newOneColor.setNamedColor("slategrey");
+    saveSpotsFile = new QFile();
+
     dataProxy = dp;
+    util = new Utilities(Q_FUNC_INFO);
+    util->setLongPrefixes(dataProxy->getLongPrefixes());
+    util->setSpecialCalls(dataProxy->getSpecialCallsigns());
     world = new World(dataProxy, Q_FUNC_INFO);
     awards = new Awards(dataProxy, Q_FUNC_INFO);
 
-
     tcpSocket = new QTcpSocket(this);
 
     dxClusterListWidget = new QListWidget();
@@ -98,10 +90,6 @@ DXClusterWidget::DXClusterWidget(DataProxy_SQLite *dp, const QString &clusterToC
     connect(dxClusterListWidget, SIGNAL(itemEntered ( QListWidgetItem *)), this, SLOT(slotClusterDXClusterWidgetItemEntered( QListWidgetItem * )) );
     connect(dxClusterListWidget, SIGNAL(itemSelectionChanged()), this, SLOT(slotClusterDXClusterWidgetItemSelected() ) );
 
-//void QListWidget::itemDoubleClicked ( QListWidgetItem * item ) [signal]
-
-    // TO BE DELETED
-    addData();
 
      //TESTADDSPOT();
        //qDebug() << "DXClusterWidget::DXClusterWidget2 - END"  << QT_ENDL;
@@ -117,8 +105,10 @@ DXClusterWidget::~DXClusterWidget()
     delete(saveSpotsFile);
 }
 
-void DXClusterWidget::initClass()
+void DXClusterWidget::init()
 {
+
+    dxSpotColor.setNamedColor("slategrey");
     dxClusterConnected = false;
     dxClusterAlreadyConnected = false;
     showDxMarathon = false;
@@ -134,7 +124,11 @@ void DXClusterWidget::initClass()
     saveSpots = false;
     myQrz = QString();
     currentLog = 0;
+    server = "dxfun.com";
+    port = quint16(8000);
     saveSpotsFile->setFileName(util->getSaveSpotsLogFile());
+
+    dxClusterSpotItem * item = new dxClusterSpotItem(dxClusterListWidget, tr("Click on connect to connect to the DX-Cluster"), awards->getDefaultColor());
 }
 
 void DXClusterWidget::setMyQRZ(const QString &_qrz)
@@ -403,12 +397,12 @@ void DXClusterWidget::slotClusterDataArrived()
               //qDebug() << "DXClusterWidget::slotClusterDataArrived: TO ALL" << QT_ENDL;
             dxSpotColor = awards->getDefaultColor();
         }
-        else if ( (dxClusterString.length()>=5) && (world->checkQRZValidFormat(tokens[1])) && (tokens[0]!="login:"))
+        //else if ( (dxClusterString.length()>=5) && (world->checkQRZValidFormat(tokens[1])) && (tokens[0]!="login:"))
+        else if ( (dxClusterString.length()>=5) && (util->isValidCall(tokens[1])) && (tokens[0]!="login:"))
         { // Freq / DXCall / Date // time
            //_qs << QRZ << Freq in MHz << lognumber;
              //qDebug() << "DXClusterWidget::slotClusterDataArrived: LENGTH >= 5" << QT_ENDL;
              //qDebug() << "DXClusterWidget::slotClusterDataArrived: token0=" << tokens[0] << " / token1=" << tokens[1] << QT_ENDL;
-
             //isADXSpot = true;
             dxCall = tokens[1];
             dxFrequency = tokens[0];
@@ -610,8 +604,6 @@ void DXClusterWidget::slotClusterInputTextChanged()
         sendButton->setText(tr("Send"));
         clearButton->setText(tr("Clear"));
     }
-    else
-    {}
 }
 
 void DXClusterWidget::setColors (const QString &_newOne, const QString &_needed, const QString &_worked, const QString &_confirmed, const QString &_default)
@@ -619,7 +611,6 @@ void DXClusterWidget::setColors (const QString &_newOne, const QString &_needed,
        //qDebug() << "DXClusterWidget::setColors: " << _newOne << "/" << _needed << "/" << _worked << "/" << _confirmed << "/" << _default << QT_ENDL;
     // Just to pass the colors to the awards class
     awards->setColors(_newOne,  _needed, _worked,  _confirmed, _default);
-
 }
 
 void DXClusterWidget::setDXClusterSpotConfig(bool _showhf, bool _showvhf, bool _showwarc, bool _showworked, bool _showconfirmed, bool _showann, bool _showwwv, bool _showwcy )
@@ -650,10 +641,6 @@ void DXClusterWidget::slotClusterDXClusterWidgetItemSelected()
         ql << "selected";
         emit dxspotclicked(ql);
     }
-    else
-    {
-    }
-
 }
 
 void DXClusterWidget::slotClusterDXClusterWidgetItemEntered( QListWidgetItem * item )
@@ -675,14 +662,7 @@ void DXClusterWidget::slotClusterDXClusterWidgetItemEntered( QListWidgetItem * i
             tip = world->getQRZEntityName(ql.at(0));
             item->setToolTip(tip);
         }
-        else
-        {
-        }
     }
-    else
-    {
-    }
-
 }
 
 
