@@ -46,7 +46,7 @@ eLogClubLog::eLogClubLog()
     connect(manager, SIGNAL(finished(QNetworkReply*)), this, SLOT(slotQsoUploadFinished(QNetworkReply*)));
     //stationCallsign = QString();
     uploadingFile = false;
-    util = new Utilities;
+    util = new Utilities(Q_FUNC_INFO);
      //qDebug()<< "eLogClubLog::eLogClubLog - END"  << QT_ENDL;
 }
 
@@ -210,10 +210,11 @@ void eLogClubLog::slotErrorManagement(QNetworkReply::NetworkError networkError)
         //qDebug()<< "eLogClubLog::slotErrorManagement: " << QString::number(networkError) << QT_ENDL;
     result = networkError;
 
-    if (result == QNetworkReply::NoError)
+    /*if (result == QNetworkReply::NoError)
     {
     }
-    else if (result == QNetworkReply::HostNotFoundError)
+    else
+    if (result == QNetworkReply::HostNotFoundError)
     {
              //qDebug()<< "eLogClubLog::slotErrorManagement: Host not found" << QT_ENDL;
     }
@@ -221,7 +222,7 @@ void eLogClubLog::slotErrorManagement(QNetworkReply::NetworkError networkError)
     {
              //qDebug()<< "eLogClubLog::slotErrorManagement: ERROR!" << QT_ENDL;
     }
-
+    */
     //actionError(result);
 }
 
