@@ -55,8 +55,10 @@ eLogQrzLog::eLogQrzLog(DataProxy_SQLite *dp, const QString &_parentFunction, con
     connect(managerLog, SIGNAL(finished(QNetworkReply*)), this, SLOT(slotManagerLogFinished(QNetworkReply*)));
     uploadingFile = false;
     logged = false;
-    util = new Utilities;
-    serviceUrl = QUrl("https://xmldata.qrz.com/xml/current/");
+    util = new Utilities(Q_FUNC_INFO);
+    util->setLongPrefixes(dataProxy->getLongPrefixes());
+    util->setSpecialCalls(dataProxy->getSpecialCallsigns());
+   // serviceUrl = QUrl("https://xmldata.qrz.com/xml/current/");
     //serviceUrl = QUrl("https://xmldata.qrz.com/xml/1.31/ ");
    //qDebug()<< "eLogQrzLog::eLogQrzLog - END"  << QT_ENDL;
 }
@@ -512,7 +514,7 @@ void eLogQrzLog::slotErrorManagement(QNetworkReply::NetworkError networkError)
        //qDebug()<< "eLogQrzLog::slotErrorManagement: " << QString::number(networkError) << QT_ENDL;
     showDebugLog (Q_FUNC_INFO, "Start: " + QString::number(networkError));
     result = networkError;
-
+    /*
     if (result == QNetworkReply::NoError)
     {
     }
@@ -525,7 +527,7 @@ void eLogQrzLog::slotErrorManagement(QNetworkReply::NetworkError networkError)
             //qDebug()<< "eLogQrzLog::slotErrorManagement: ERROR!" << QT_ENDL;
     }
 
-    //actionError(result);
+    */
     showDebugLog (Q_FUNC_INFO, "END");
 }
 
@@ -581,7 +583,7 @@ void eLogQrzLog::checkQRZ(const QString &_qrz)
         showDebugLog (Q_FUNC_INFO, "CALL not valid");
         return;
     }
-    serviceUrl = QUrl("https://xmldata.qrz.com/xml/current/");
+    //serviceUrl = QUrl("https://xmldata.qrz.com/xml/current/");
 
     if (!canConnect())
     {
@@ -745,7 +747,7 @@ int eLogQrzLog::sendDataParams(const QUrlQuery &_params)
     params.setQuery(postData);
 
     postData = params.query(QUrl::FullyEncoded).toUtf8();
-
+    serviceUrl = QUrl("https://xmldata.qrz.com/xml/current/");
     QNetworkRequest request(serviceUrl);
     request.setHeader(QNetworkRequest::ContentTypeHeader, "application/x-www-form-urlencoded");
 
