@@ -30,7 +30,7 @@ MainWindowInputEQSL::MainWindowInputEQSL(DataProxy_SQLite *dp, QWidget *parent)
     QWidget(parent)
 {
        //qDebug() << "MainWindowInputEQSL::MainWindowInputEQSL"   << QT_ENDL;
-    util = new Utilities;
+    util = new Utilities(Q_FUNC_INFO);
     dataProxy = dp;
 
     eqslSentComboBox = new QComboBox;
@@ -141,7 +141,6 @@ void MainWindowInputEQSL::createUI()
     connect(lotwSentComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(slotLotwSentComboBoxChanged() ) )  ;
     connect(lotwRecComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(slotLotwRecvComboBoxChanged() ) ) ;
     connect(qrzcomComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(slotQRZCOMComboBoxChanged() ) )  ;
-
 }
 
 
@@ -169,10 +168,9 @@ void MainWindowInputEQSL::setDefaultData()
     //qsAux << tr("Y-Uploaded") << tr("N-Do not upload") << tr("M-Modified");
     clublogComboBox->addItems(clubLogStatusList);
     qrzcomComboBox->addItems(clubLogStatusList);
-
     queueSentByDefault = true;
-
 }
+
 void MainWindowInputEQSL::clear()
 {
       //qDebug() << "MainWindowInputEQSL::clear"  << QT_ENDL;
@@ -201,7 +199,6 @@ void MainWindowInputEQSL::clear()
     lotwRecQDateEdit->setDate(util->getDefaultDate());
     clublogQDateEdit->setDate(util->getDefaultDate());
     qrzcomQDateEdit->setDate(util->getDefaultDate());
-
 }
 
 
@@ -231,7 +228,6 @@ QString MainWindowInputEQSL::getEQSLRecStatus()
     //    return QString();
     //}
     return _pm;
-
 }
 
 QString MainWindowInputEQSL::getEQSLSenStatus()
@@ -392,33 +388,34 @@ void MainWindowInputEQSL::slotLotwRecvComboBoxChanged(){
 //R-Requested-2
 //I-Ignore-3
 //V-Verified-4
-
-
-
     int i = lotwRecComboBox->currentIndex();
 
     switch (i)
     {
         case 0:
+            lotwRecQDateEdit->setVisible(true);
             lotwRecQDateEdit->setEnabled(true);
             lotwRecQDateEdit->setDate((QDateTime::currentDateTime()).date());
 
         break;
         case 2:
+            lotwRecQDateEdit->setVisible(true);
             lotwRecQDateEdit->setEnabled(true);
             lotwRecQDateEdit->setDate((QDateTime::currentDateTime()).date());
         break;
         case 3:
+            lotwRecQDateEdit->setVisible(true);
             lotwRecQDateEdit->setEnabled(true);
         break;
         case 4:
+            lotwRecQDateEdit->setVisible(true);
             lotwRecQDateEdit->setEnabled(true);
         break;
         default: //NO
+            lotwRecQDateEdit->setVisible(false);
             lotwRecQDateEdit->setEnabled(false);
         break;
     }
-
 }
 
 
@@ -436,23 +433,28 @@ void MainWindowInputEQSL::slotLotwSentComboBoxChanged(){
     switch (i)
     {
         case 0:
+            lotwSentQDateEdit->setVisible(true);
             lotwSentQDateEdit->setEnabled(true);
             lotwSentQDateEdit->setDate((QDateTime::currentDateTime()).date());
         break;
         case 2:
+            lotwSentQDateEdit->setVisible(true);
             lotwSentQDateEdit->setEnabled(true);
             lotwSentQDateEdit->setDate((QDateTime::currentDateTime()).date());
         break;
         case 3:
+            lotwSentQDateEdit->setVisible(true);
             lotwSentQDateEdit->setEnabled(true);
             lotwSentQDateEdit->setDate((QDateTime::currentDateTime()).date());
         break;
         case 4:
+            lotwSentQDateEdit->setVisible(true);
             lotwSentQDateEdit->setEnabled(true);
             lotwSentQDateEdit->setDate((QDateTime::currentDateTime()).date());
         break;
 
         default: //NO
+            lotwSentQDateEdit->setVisible(false);
             lotwSentQDateEdit->setEnabled(false);
         break;
     }
@@ -474,28 +476,30 @@ void MainWindowInputEQSL::sloteQSLRecvComboBoxChanged(){
     switch (i)
     {
         case 0:
+            eqslRecQDateEdit->setVisible(true);
             eqslRecQDateEdit->setEnabled(true);
             eqslRecQDateEdit->setDate((QDateTime::currentDateTime()).date());
         break;
         case 2:
+            eqslRecQDateEdit->setVisible(true);
             eqslRecQDateEdit->setEnabled(true);
             eqslRecQDateEdit->setDate((QDateTime::currentDateTime()).date());
         break;
         case 3:
+            eqslRecQDateEdit->setVisible(true);
             eqslRecQDateEdit->setEnabled(true);
             eqslRecQDateEdit->setDate((QDateTime::currentDateTime()).date());
         break;
         case 4:
+            eqslRecQDateEdit->setVisible(true);
             eqslRecQDateEdit->setEnabled(true);
             eqslRecQDateEdit->setDate((QDateTime::currentDateTime()).date());
         break;
         default: //NO
+            eqslRecQDateEdit->setVisible(false);
             eqslRecQDateEdit->setEnabled(false);
         break;
-
-
     }
-
 }
 
 
@@ -513,23 +517,28 @@ void MainWindowInputEQSL::sloteQSLSentComboBoxChanged(){
     switch (i)
     {
         case 0:
+            eqslSentQDateEdit->setVisible(true);
             eqslSentQDateEdit->setEnabled(true);
             eqslSentQDateEdit->setDate((QDateTime::currentDateTime()).date());
         break;
         case 2:
+            eqslSentQDateEdit->setVisible(true);
             eqslSentQDateEdit->setEnabled(true);
             eqslSentQDateEdit->setDate((QDateTime::currentDateTime()).date());
         break;
         case 3:
+            eqslSentQDateEdit->setVisible(true);
             eqslSentQDateEdit->setEnabled(true);
             eqslSentQDateEdit->setDate((QDateTime::currentDateTime()).date());
         break;
         case 4:
+            eqslSentQDateEdit->setVisible(true);
             eqslSentQDateEdit->setEnabled(true);
             eqslSentQDateEdit->setDate((QDateTime::currentDateTime()).date());
         break;
 
         default: //NO
+            eqslSentQDateEdit->setVisible(false);
             eqslSentQDateEdit->setEnabled(false);
         break;
     }
@@ -546,14 +555,17 @@ void MainWindowInputEQSL::slotClubLogComboBoxChanged()
     switch (i)
     {
         case 0:
+            clublogQDateEdit->setVisible(true);
             clublogQDateEdit->setEnabled(true);
             clublogQDateEdit->setDate((QDateTime::currentDateTime()).date());
         break;
         case 2:
+            clublogQDateEdit->setVisible(true);
             clublogQDateEdit->setEnabled(true);
             clublogQDateEdit->setDate((QDateTime::currentDateTime()).date());
         break;
         default: //NO
+            clublogQDateEdit->setVisible(false);
             clublogQDateEdit->setEnabled(false);
         break;
     }
@@ -582,14 +594,17 @@ void MainWindowInputEQSL::slotQRZCOMComboBoxChanged()
     switch (i)
     {
         case 0:
+            qrzcomQDateEdit->setVisible(true);
             qrzcomQDateEdit->setEnabled(true);
             qrzcomQDateEdit->setDate((QDateTime::currentDateTime()).date());
         break;
         case 2:
+            qrzcomQDateEdit->setVisible(true);
             qrzcomQDateEdit->setEnabled(true);
             qrzcomQDateEdit->setDate((QDateTime::currentDateTime()).date());
         break;
         default: //NO
+            qrzcomQDateEdit->setVisible(false);
             qrzcomQDateEdit->setEnabled(false);
         break;
     }
