@@ -33,7 +33,7 @@ LogWindow::LogWindow(DataProxy_SQLite *dp, QWidget *parent) : QWidget(parent)
     dataProxy = dp;
     //sortingThroughProxyModel = false;
     logModel = new LogModel(dataProxy, this);
-    util = new Utilities;
+    util = new Utilities(Q_FUNC_INFO);
     connect(logModel, SIGNAL(queryError(QString, QString, QString, QString)), this, SLOT(slotQueryErrorManagement(QString, QString, QString, QString)) );
     logView = new QTableView;
     columns.clear();
@@ -283,10 +283,7 @@ void LogWindow::rightButtonFromLogMenu(const int trow)
     checkDXHeatFromLogAct->setData(trow);
 
         menu.addSeparator();
-        if (qslSent)
-        {
-        }
-        else
+        if (!qslSent)
         {
             QMenu *menuSentQsl = menu.addMenu(tr("QSL Send"));
             menuSentQsl->addAction(qslSentViaBureauFromLogAct);
@@ -295,10 +292,7 @@ void LogWindow::rightButtonFromLogMenu(const int trow)
             qslSentViaDirectFromLogAct->setData(trow);
         }
 
-        if (qslReceived)
-        {
-        }
-        else
+        if (!qslReceived)
         {
             QMenu *menuRecQsl = menu.addMenu(tr("QSL Rcvd"));
             menuRecQsl->addAction(qslRecViaBureauFromLogAct);
