@@ -46,11 +46,12 @@ int main(int argc, char *argv[])
     //qDebug() << "KLog Main: Start! " << QT_ENDL;
     //qDebug() << "KLog Main: " << QSslSocket::supportsSsl() << QSslSocket::sslLibraryBuildVersionString() << QSslSocket::sslLibraryVersionString() << QT_ENDL;
     QT_REQUIRE_VERSION(argc, argv, "5.9")
+    //qDebug() << QT_VERSION_STR;
 
     QDir d1 = QDir();
     //QCoreApplication::setApplicationVersion(QString(APP_VERSION));
     //qDebug() << "KLog Main STARTED: " << version << QT_ENDL;
-    Utilities util = Utilities();
+    Utilities util(Q_FUNC_INFO);
     QStringList arguments;
     QTextStream cout(stdout);
     //QCoreApplication::setOrganizationName("EA4K");
@@ -284,19 +285,7 @@ int main(int argc, char *argv[])
             {
                     //qDebug() << "MAIN:  KLogDir has just been created and pointed " << QT_ENDL;
             }
-            else
-            {
-                    //qDebug() << "MAIN:  KLogDir has just been created and pointed FAILED! " << QT_ENDL;
-            }
         }
-        else
-        {
-                //qDebug() << "MAIN:  KLogDir can not be created?? " << QT_ENDL;
-        }
-    }
-    else
-    {
-        //qDebug() << "MAIN:  KLogDir already existed!! " << QT_ENDL;
     }
     //qDebug() << "KLog Main: Setting klog dir - finished: " << (QTime::currentTime()).toString("HH:mm:ss") << QT_ENDL;
 
@@ -311,22 +300,24 @@ int main(int argc, char *argv[])
 
         StartWizard *wizard = new StartWizard(klogDir, version);
         wizard->setModal(true);
-        int inMemory = wizard->exec();
+        //int inMemory = wizard->exec();
+        wizard->exec();
         //qDebug() << "MAIN: Wizard inMemory: " << QString::number(inMemory) << QT_ENDL;
-        inMemory = 1;
+        //inMemory = 1;
 
-        if (inMemory == 1)
-        {
+        //if (inMemory == 1)
+        //{
             //qDebug() << "MAIN: Wizard accepted " << QString::number(inMemory) << " ... Will run in Memory " << QT_ENDL;
             MainWindow mw(klogDir, version);
             mw.init();
             splash.finish(&mw);
             //mw.checkIfNewVersion();
             //mw.recommendBackupIfNeeded();
+            mw.showNotWar();
             mw.show();
             return app.exec();
-        }
-
+        //}
+        /*
         else
         {
                //qDebug() << "MAIN: Wizard cancelled " << QString::number(inMemory) << " ... should close " << QT_ENDL;
@@ -371,8 +362,8 @@ int main(int argc, char *argv[])
             }
             return 0;
         }
+        */
     }
-
     else
     {
         //qDebug() << "Main: Start of DB Activities" << (QTime::currentTime()).toString("HH:mm:ss") << QT_ENDL;
@@ -395,24 +386,28 @@ int main(int argc, char *argv[])
         //qDebug() << "KLog Main-99" << (QTime::currentTime()).toString("HH:mm:ss") << QT_ENDL;
         splash.show();
         //qDebug() << "KLog Main-100" << (QTime::currentTime()).toString("HH:mm:ss") << QT_ENDL;
+        splash.showMessage ("Creating window...");
         MainWindow mw(klogDir, version);
         //qDebug() << "KLog Main-101" << (QTime::currentTime()).toString("HH:mm:ss") << QT_ENDL;
+        splash.showMessage ("Initializing window...");
         mw.init();
         //qDebug() << "KLog Main-102" << (QTime::currentTime()).toString("HH:mm:ss") << QT_ENDL;
-        splash.finish(&mw);
-        //qDebug() << "KLog Main-103" << (QTime::currentTime()).toString("HH:mm:ss") << QT_ENDL;
+        splash.showMessage ("Checking for new versions...");
         mw.checkIfNewVersion();
-        //qDebug() << "KLog Main-104" << (QTime::currentTime()).toString("HH:mm:ss") << QT_ENDL;
+        splash.showMessage ("Checking if backup is needed...");
+        //qDebug() << "KLog Main-103" << (QTime::currentTime()).toString("HH:mm:ss") << QT_ENDL;
         mw.recommendBackupIfNeeded();
-        //qDebug() << "KLog Main-105" << (QTime::currentTime()).toString("HH:mm:ss") << QT_ENDL;
+        splash.showMessage ("Showing window...");
+        //qDebug() << "KLog Main-104" << (QTime::currentTime()).toString("HH:mm:ss") << QT_ENDL;
         mw.show();
+        //qDebug() << "KLog Main-105" << (QTime::currentTime()).toString("HH:mm:ss") << QT_ENDL;
+        splash.finish(&mw);
+        mw.showNotWar();
         //qDebug() << "KLog Main-106" << (QTime::currentTime()).toString("HH:mm:ss") << QT_ENDL;
         return app.exec();
         //qDebug() << "KLog Main-107" << (QTime::currentTime()).toString("HH:mm:ss") << QT_ENDL;
     }
         //qDebug() << "KLog Main-END: " << (QTime::currentTime()).toString("HH:mm:ss")  << QT_ENDL;
-
-    //return app.exec();
 }
 
 
