@@ -30,7 +30,7 @@
 MainQSOEntryWidget::MainQSOEntryWidget(DataProxy_SQLite *dp, QWidget *parent) : QWidget(parent)
 {
       //qDebug()<< "MainQSOEntryWidget::MainQSOEntryWidget " << QT_ENDL;
-    emit debugLog(Q_FUNC_INFO, "Start", Debug);
+    logEvent (Q_FUNC_INFO, "Start", Debug);
 
     upAndRunning = false;
     dataProxy = dp;
@@ -46,23 +46,24 @@ MainQSOEntryWidget::MainQSOEntryWidget(DataProxy_SQLite *dp, QWidget *parent) :
     OKButton = new QPushButton(tr("&Add"), this);
     clearButton = new QPushButton(tr("&Clear"), this);
     timer = new QTimer(this);
-    util = new Utilities;
+    util = new Utilities(Q_FUNC_INFO);
     realTime = true;
-    duplicatedQSOSlotInSecs = 0;
+    duplicatedQSOSlotInSecs = 15;
     delayInputTimer = new QTimer;
-
-    //hamlib = new HamLibClass();
-
+    logLevel = None;
 
     createUI();
     setInitialData();
     //installEventFilter (this);
-    emit debugLog(Q_FUNC_INFO, "END", Debug);
+    logEvent (Q_FUNC_INFO, "END", Debug);
       //qDebug()<< "MainQSOEntryWidget::MainQSOEntryWidget: - END" << QT_ENDL;
 }
+
 MainQSOEntryWidget::~MainQSOEntryWidget()
 {
+    logEvent (Q_FUNC_INFO, "Start", Debug);
     delete(util);
+    logEvent (Q_FUNC_INFO, "END", Debug);
 }
 
 /*
@@ -77,7 +78,7 @@ void MainQSOEntryWidget::slotRealTimeButtonResize()
 void MainQSOEntryWidget::createUI()
 {
       //qDebug()<< "MainQSOEntryWidget::createUI" << QT_ENDL;
-    emit debugLog(Q_FUNC_INFO, "Start", Debug);
+    logEvent (Q_FUNC_INFO, "Start", Debug);
     qrzLineEdit->setToolTip(tr("Callsign of the QSO."));
     bandComboBox->setToolTip(tr("Band of the QSO."));
     modeComboBox->setToolTip(tr("Mode of the QSO."));
@@ -116,6 +117,7 @@ void MainQSOEntryWidget::createUI()
     QHBoxLayout *buttonsLayout = new QHBoxLayout;
     buttonsLayout->addWidget(OKButton);
     buttonsLayout->addWidget(clearButton);
+    dateEdit->setCalendarPopup (true);;
 
     dateEdit->setDisplayFormat("yyyy-MM-dd");
     timeEdit->setDisplayFormat("HH:mm:ss");
@@ -131,9 +133,8 @@ void MainQSOEntryWidget::createUI()
     palBlack.setColor(QPalette::Text, Qt::black);
     palWhite.setColor(QPalette::Text, Qt::white);
 
+    connect(util, SIGNAL(debugLog(QString, QString, DebugLogLevel)), this, SLOT(slotCaptureDebugLogs(QString, QString, DebugLogLevel)));
     connect(qrzLineEdit, SIGNAL(returnPressed()), this, SLOT(slotOKButtonClicked() ) );
-    //connect(qrzLineEdit, SIGNAL(res), this, SLOT(slotOKButtonClicked() ) );
-    //connect(qrzLineEdit, SIGNAL(textChanged(QString)), this, SLOT(slotQRZTextChanged() ) );
     connect(qrzLineEdit, SIGNAL(textChanged(QString)), this, SLOT(slotStartDelayInputTimer() ) );
     connect(delayInputTimer, SIGNAL(timeout()), this, SLOT(slotDelayInputTimedOut() ) );
 
@@ -147,29 +148,42 @@ void MainQSOEntryWidget::createUI()
     //connect(realtimeButton, SIGNAL(clicked()), this, SLOT(slotRealtimeButtonClicked()) );
     connect(realtimeCheckBox, SIGNAL(clicked()), this, SLOT(slotCheckBoxClicked()));
     connect(manualModeCheckBox, SIGNAL(clicked()), this, SLOT(slotManualModeCheckBoxClicked()));
-      //qDebug()<< "MainQSOEntryWidget::createUI-END" << QT_ENDL;
+    //qDebug()<< "MainQSOEntryWidget::createUI-END" << QT_ENDL;
 
     QWidget::setTabOrder (qrzLineEdit, dateEdit);
     QWidget::setTabOrder (dateEdit, timeEdit);
 
-    emit debugLog(Q_FUNC_INFO, "END", Debug);
-
+    logEvent (Q_FUNC_INFO, "END", Debug);
     //qDebug() << Q_FUNC_INFO << ": (" << QString::number(this->size ().width ()) << "/" << QString::number(this->size ().height ()) << ")" ;
 }
 
-/*
-void MainQSOEntryWidget::resizeEvent(QResizeEvent *event)
+void MainQSOEntryWidget::setShowSeconds(const bool &t)
 {
-    //qDebug() << Q_FUNC_INFO;
-    slotRealTimeButtonResize();
-
+    if (t)
+    {
+        timeEdit->setDisplayFormat("HH:mm:ss");
+    }
+    else
+    {
+        timeEdit->setDisplayFormat("HH:mm");
+    }
 }
-*/
 
+void MainQSOEntryWidget::setLogLevel (const DebugLogLevel _b)
+{
+    logEvent (Q_FUNC_INFO, "Start", Debug);
+    logLevel = _b;
+    logEvent (Q_FUNC_INFO, "END", Debug);
+}
+
+void MainQSOEntryWidget::setCallValidation (const bool _b)
+{
+    util->setCallValidation(_b);
+}
 
 void MainQSOEntryWidget::slotCheckBoxClicked()
 {
-   //qDebug() << Q_FUNC_INFO;
+   logEvent (Q_FUNC_INFO, "Start", Debug);
     if (realtimeCheckBox->isChecked())
     {
         realTime = true;
@@ -182,14 +196,14 @@ void MainQSOEntryWidget::slotCheckBoxClicked()
         //realtimeButton->setIcon(QIcon(":/img/stop.svg"));
         timeEdit->setBackgroundRole(QPalette::BrightText);
     }
+    logEvent (Q_FUNC_INFO, "END", Debug);
 }
 
 void MainQSOEntryWidget::slotManualModeCheckBoxClicked()
 {
-    //qDebug() << Q_FUNC_INFO;
+    logEvent (Q_FUNC_INFO, "Start", Debug);
     if (manualModeCheckBox->isChecked())
     {
-        //qDebug() << Q_FUNC_INFO;
         slotClearButtonClicked();
         emit manualModeSignal(true);
         //stop hamlib and wsjt-x communication;
@@ -199,12 +213,13 @@ void MainQSOEntryWidget::slotManualModeCheckBoxClicked()
         emit manualModeSignal(false);
         //start hamlib and wsjt-x communication;
     }
+    logEvent (Q_FUNC_INFO, "END", Debug);
 }
 
 /*
 void MainQSOEntryWidget::slotRealtimeButtonClicked()
 {
-    emit debugLog(Q_FUNC_INFO, "Start", Debug);
+    logEvent (Q_FUNC_INFO, "Start", Debug);
 
     if (realtimeButton->isChecked())
     {
@@ -219,36 +234,38 @@ void MainQSOEntryWidget::slotRealtimeButtonClicked()
         timeEdit->setBackgroundRole(QPalette::BrightText);
     }
 
-    emit debugLog(Q_FUNC_INFO, "END", Debug);
+    logEvent (Q_FUNC_INFO, "END", Debug);
 }
 */
+
 void MainQSOEntryWidget::setCleaning (const bool _c)
 {
-    emit debugLog(Q_FUNC_INFO, "Start", Debug);
+    logEvent (Q_FUNC_INFO, "Start", Debug);
     cleaning = _c;
-    emit debugLog(Q_FUNC_INFO, "END", Debug);
+    logEvent (Q_FUNC_INFO, "END", Debug);
 }
 
 void MainQSOEntryWidget::slotQRZTextChanged()
 {
+    logEvent (Q_FUNC_INFO, "Start: " + qrzLineEdit->text(), Debug);
     //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: " << qrzLineEdit->text() << " / Length: " << QString::number((qrzLineEdit->text()).size()) << "###### START ######" << QT_ENDL;
-    emit debugLog(Q_FUNC_INFO, "Start", Debug);
+    logEvent (Q_FUNC_INFO, "Start", Debug);
 
     if ((qrzLineEdit->text()).length()<1)
     {
-        //qDebug() << Q_FUNC_INFO;
+       //qDebug() << Q_FUNC_INFO << ": qrz length <1";
         slotClearButtonClicked();
-        emit debugLog(Q_FUNC_INFO, "END-1", Debug);
+        logEvent (Q_FUNC_INFO, "END-1", Debug);
         //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: QRZ <1 - END" << QT_ENDL;
     return;
     }
     int cursorP = qrzLineEdit->cursorPosition();
-    //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: cursor position: " << QString::number(cursorP) << QT_ENDL;
+   //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: cursor position: " << QString::number(cursorP) << QT_ENDL;
     qrzLineEdit->setText((qrzLineEdit->text()).toUpper());
     if (cleaning)
     {
         //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: Cleaning - END" << QT_ENDL;
-        emit debugLog(Q_FUNC_INFO, "END-2", Debug);
+        logEvent (Q_FUNC_INFO, "END-2", Debug);
         return;
     }
 
@@ -256,26 +273,26 @@ void MainQSOEntryWidget::slotQRZTextChanged()
     {
         //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: qrzAutoChanging - END" << QT_ENDL;
         qrzAutoChanging = false;
-        emit debugLog(Q_FUNC_INFO, "END-3", Debug);
+        logEvent (Q_FUNC_INFO, "END-3", Debug);
         return;
     }
 
     qrzAutoChanging = true;
 
-   //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: cursor position.1: " << QString::number(cursorP) << QT_ENDL;
+    //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: cursor position.1: " << QString::number(cursorP) << QT_ENDL;
 
     if ( (qrzLineEdit->text()).endsWith(' ') )
     {/*Remove the space and moves the focus to SRX to write the RX exchange*/
         previousQRZ = (qrzLineEdit->text()).simplified();
         qrzLineEdit->setText(previousQRZ);
-        //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: Space detected" << QT_ENDL;
+       //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: Space detected" << QT_ENDL;
     }
 
     //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: Simplifiying & Capitalizing" << QT_ENDL;
     qrzLineEdit->setText(((qrzLineEdit->text())).simplified());
     qrzLineEdit->setText((qrzLineEdit->text()).remove(" "));
 
-    //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: checking for invalid chars" << QT_ENDL;
+   //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: checking for invalid chars" << QT_ENDL;
     //TODO: This validCharactersInCall may be removed?
     InValidCharsInPrevCall = validCharactersInCall(qrzLineEdit->text());
     //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: checking for invalid chars 00 " << QT_ENDL;
@@ -284,7 +301,7 @@ void MainQSOEntryWidget::slotQRZTextChanged()
         qrzLineEdit->setPalette(palRed);
         //emit showInfoLabel(tr("Callsign not valid"));
         //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: QRZ not valid - Red" << QT_ENDL;
-        emit debugLog(Q_FUNC_INFO, "END-4", Debug);
+        //logEvent (Q_FUNC_INFO, "END-4", Debug);
     }
     else
     {
@@ -306,7 +323,7 @@ void MainQSOEntryWidget::slotQRZTextChanged()
     if (((qrzLineEdit->text()).length() < 1))
     { // If QRZ box is blank, Information labels should be cleared.
         slotClearButtonClicked();
-        emit debugLog(Q_FUNC_INFO, "END-5", Debug);
+        logEvent (Q_FUNC_INFO, "END-5", Debug);
         return;
     }
     */
@@ -315,9 +332,9 @@ void MainQSOEntryWidget::slotQRZTextChanged()
     if (qrzSmallModDontCalculate)
     //if ((modify) || ((qrzLineEdit->text()).length() < 1) || (qrzSmallModDontCalculate))
     {
-        //qDebug() << "MainQSOEntryWidget::slotQRZTextChanged: qrzSmallModDontCalculate < 1" << QT_ENDL;
+       //qDebug() << "MainQSOEntryWidget::slotQRZTextChanged: qrzSmallModDontCalculate < 1" << QT_ENDL;
         qrzSmallModDontCalculate=false;
-        emit debugLog(Q_FUNC_INFO, "END-6", Debug);
+        logEvent (Q_FUNC_INFO, "END-6", Debug);
         return;
     }
 
@@ -327,7 +344,7 @@ void MainQSOEntryWidget::slotQRZTextChanged()
 
     if ((currentQrz).count('\\'))
     { // Replaces \ by / to ease operation.
-        //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: Replacing \\ by /" << QT_ENDL;
+       //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: Replacing \\ by /" << QT_ENDL;
         currentQrz.replace(QChar('\\'), QChar('/'));
         qrzLineEdit->setText(currentQrz);
     }
@@ -336,18 +353,23 @@ void MainQSOEntryWidget::slotQRZTextChanged()
     //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: cursor position.3: " << QString::number(cursorP) << QT_ENDL;
     if (cursorP>currentQrz.length())
     {// A Space that has been removed without updating the cursor
-         //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: cursorP > currentQRZ.length" << QT_ENDL;
+        //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: cursorP > currentQRZ.length" << QT_ENDL;
     }
     else
     {
-        if (((currentQrz.at(cursorP-1)).isSpace()) && (cursorP!=0))
+       //qDebug() << Q_FUNC_INFO << " cursorP<currentQrz.length: " << QString::number(cursorP);
+
+        if (cursorP>0)
         {
-            //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: cursor position.5: " << QString::number(cursorP) << QT_ENDL;
-            previousQRZ = currentQrz.remove(cursorP-1, 1);
-            //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: cursor position.6: " << QString::number(cursorP) << QT_ENDL;
-            cursorP--;
-            //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: cursor position.7: " << QString::number(cursorP) << QT_ENDL;
-            qrzLineEdit->setText(previousQRZ);
+            if ((currentQrz.at(cursorP-1)).isSpace())
+            {
+               //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: cursor position.5: " << QString::number(cursorP) << QT_ENDL;
+                previousQRZ = currentQrz.remove(cursorP-1, 1);
+               //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: cursor position.6: " << QString::number(cursorP) << QT_ENDL;
+                cursorP--;
+               //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: cursor position.7: " << QString::number(cursorP) << QT_ENDL;
+                qrzLineEdit->setText(previousQRZ);
+            }
         }
     }
     currentQrz = qrzLineEdit->text();
@@ -355,70 +377,68 @@ void MainQSOEntryWidget::slotQRZTextChanged()
     emit currentQRZSignal(currentQrz);
 
     qrzSmallModDontCalculate = false; // If the text has not been modified in this method
-    //qDebug() << "MainQSOEntryWidget::slotQRZTextChanged: cursorP at the end : " << QString::number(cursorP) << QT_ENDL;
+    //qDebug() << "MainQSOEntryWidget::slotQRZTextChanged: cursorP at the end : " << QString::number(cursorP);
     qrzLineEdit->setCursorPosition(cursorP);
     checkIfDupe(Q_FUNC_INFO);
     qrzAutoChanging = false;
-    emit debugLog(Q_FUNC_INFO, "Start", Debug);
-
-    //qDebug() << "MainQSOEntryWidget::slotQRZTextChanged: END" << QT_ENDL;
+    logEvent (Q_FUNC_INFO, "END", Debug);
 }
 
 void MainQSOEntryWidget::setCurrentQRZ(const QString &_qrz)
 {
-    emit debugLog(Q_FUNC_INFO, "Start", Debug);
+    logEvent (Q_FUNC_INFO, "Start", Debug);
     currentQrz = _qrz;
-    emit debugLog(Q_FUNC_INFO, "END", Debug);
+    logEvent (Q_FUNC_INFO, "END", Debug);
 }
 
 void MainQSOEntryWidget::slotBandComboBoxChanged(const QString &_b){
     //qDebug() << Q_FUNC_INFO << ": " << _b;
 
-    emit debugLog(Q_FUNC_INFO, "Start", Debug);
+    logEvent (Q_FUNC_INFO, "Start", Debug);
     bottomBandLimit = dataProxy->getLowLimitBandFromBandName (_b);
     upperBandLimit = dataProxy->getUpperLimitBandFromBandName (_b);
     emit bandChanged(_b);
     checkIfDupe(Q_FUNC_INFO);
-    emit debugLog(Q_FUNC_INFO, "END", Debug);
+    logEvent (Q_FUNC_INFO, "END", Debug);
     //qDebug() << Q_FUNC_INFO << " - END";
 }
 
 void MainQSOEntryWidget::slotModeComboBoxChanged(const QString &_m)
 {
-    emit debugLog(Q_FUNC_INFO, "Start", Debug);
+    logEvent (Q_FUNC_INFO, "Start", Debug);
 
     emit modeChanged(_m);
     checkIfDupe(Q_FUNC_INFO);
-    emit debugLog(Q_FUNC_INFO, "END", Debug);
+    logEvent (Q_FUNC_INFO, "END", Debug);
 }
 
 void MainQSOEntryWidget::slotOKButtonClicked()
 {
-    emit debugLog(Q_FUNC_INFO, "Start", Debug);
+    logEvent (Q_FUNC_INFO, "Start", Debug);
     if ((qrzLineEdit->text()).length()<1)
     {
         return;
     }
     emit OKClicked();
-    emit debugLog(Q_FUNC_INFO, "END", Debug);
+    logEvent (Q_FUNC_INFO, "END", Debug);
 }
 
 void MainQSOEntryWidget::slotClearButtonClicked()
 {
     //qDebug() << "MainQSOEntryWidget::slotClearButtonClicked: "  << QT_ENDL;
-    emit debugLog(Q_FUNC_INFO, "Start", Debug);
+    logEvent (Q_FUNC_INFO, "Start", Debug);
     setCleaning (true);
     clear();
     emit clearForNextQSOSignal(Q_FUNC_INFO);
     //setModify(false);
     checkIfDupe(Q_FUNC_INFO);
     setCleaning (false);
-    emit debugLog(Q_FUNC_INFO, "END", Debug);
+    logEvent (Q_FUNC_INFO, "END", Debug);
 }
 
 void MainQSOEntryWidget::clear()
 {
-    emit debugLog(Q_FUNC_INFO, "Start", Debug);
+    logEvent (Q_FUNC_INFO, "Start", Debug);
 
     //qDebug() << Q_FUNC_INFO << QT_ENDL;
 
@@ -429,13 +449,13 @@ void MainQSOEntryWidget::clear()
     qrzLineEdit->setFocus(Qt::OtherFocusReason);
 
     //cleaning = false;
-    emit debugLog(Q_FUNC_INFO, "END", Debug);
+    logEvent (Q_FUNC_INFO, "END", Debug);
 }
 
 void MainQSOEntryWidget::setInitialData()
 {
       //qDebug()<< "MainQSOEntryWidget::setInitialData" << QT_ENDL;
-    emit debugLog(Q_FUNC_INFO, "Start", Debug);
+    logEvent (Q_FUNC_INFO, "Start", Debug);
     //Default band/modes
     modify = false;
     qrzAutoChanging = false;
@@ -443,6 +463,9 @@ void MainQSOEntryWidget::setInitialData()
     qrzSmallModDontCalculate=false;
     previousQRZ = QString();
 
+    util->setLongPrefixes(dataProxy->getLongPrefixes());
+    util->setSpecialCalls(dataProxy->getSpecialCallsigns());
+
     bands.clear();
     modes.clear();
     bands << "10M" << "15M" << "20M" << "40M" << "80M" << "160M";
@@ -462,12 +485,13 @@ void MainQSOEntryWidget::setInitialData()
 
     timer->start(1000);
 
-    emit debugLog(Q_FUNC_INFO, "END", Debug);
+    logEvent (Q_FUNC_INFO, "END", Debug);
      //qDebug()<< "MainQSOEntryWidget::setInitialData-END" << QT_ENDL;
 }
 
 bool MainQSOEntryWidget::updateBandComboBox(const QString &_band)
 {
+    logEvent (Q_FUNC_INFO, "Start: " + _band, Debug);
     //qDebug() << Q_FUNC_INFO << ": " << _band << QT_ENDL;
     //QString _currentBand = getBand();
     if (!isBandExisting(_band))
@@ -493,16 +517,18 @@ bool MainQSOEntryWidget::updateBandComboBox(const QString &_band)
         else
         {
             //qDebug() << Q_FUNC_INFO << ": (END) Band is NOT  valid: " <<_band<< endl;
+            logEvent (Q_FUNC_INFO, "END-1", Debug);
             return false;
         }
     }
     //qDebug() << Q_FUNC_INFO << ": Band already existing, no need to add"  << QT_ENDL;
+    logEvent (Q_FUNC_INFO, "END", Debug);
     return true;
 }
 
 void MainQSOEntryWidget::setBands(const QStringList _bands)
 {
-    emit debugLog(Q_FUNC_INFO, "Start", Debug);
+    logEvent (Q_FUNC_INFO, "Start: " + QString::number(_bands.length ()), Debug);
     //qDebug()<< "MainQSOEntryWidget::setBands" << QT_ENDL;
     //foreach(QString i, _bands)
     //{
@@ -516,13 +542,13 @@ void MainQSOEntryWidget::setBands(const QStringList _bands)
     bandComboBox->addItems(bands);
     emit validBands(_bands);
     //selectDefaultBand(true);
-    emit debugLog(Q_FUNC_INFO, "END", Debug);
+    logEvent (Q_FUNC_INFO, "END", Debug);
     //qDebug()<< "MainQSOEntryWidget::setBands-END" << QT_ENDL;
 }
 
 void MainQSOEntryWidget::setModes(const QStringList _modes)
 {
-    emit debugLog(Q_FUNC_INFO, "Start", Debug);
+    logEvent (Q_FUNC_INFO, "Start", Debug);
     modes.clear();
     modes = _modes;
     modes.removeDuplicates();
@@ -530,22 +556,25 @@ void MainQSOEntryWidget::setModes(const QStringList _modes)
     modeComboBox->clear();
     modeComboBox->addItems(modes);
     selectDefaultMode(true);
-    emit debugLog(Q_FUNC_INFO, "END", Debug);
+    logEvent (Q_FUNC_INFO, "END", Debug);
 
 }
 
 QStringList MainQSOEntryWidget::getModes()
 {
+    logEvent (Q_FUNC_INFO, "Start-End", Debug);
     return modes;
 }
 
 bool MainQSOEntryWidget::setFreq(const double _f, bool isRX)
 {
     //qDebug() << Q_FUNC_INFO << ": " << QString::number(_f);
+    logEvent (Q_FUNC_INFO, "Start", Debug);
     if (isRX)
     {
         if (util->isSameFreq (freqRX, _f))
         {
+            logEvent (Q_FUNC_INFO, "END-1", Debug);
             return true;
         }
         freqRX = _f;
@@ -553,6 +582,7 @@ bool MainQSOEntryWidget::setFreq(const double _f, bool isRX)
 
     if (util->isSameFreq (freqTX, _f))
     {
+        logEvent (Q_FUNC_INFO, "END-2", Debug);
         return true;
     }
     freqTX = _f;
@@ -561,6 +591,7 @@ bool MainQSOEntryWidget::setFreq(const double _f, bool isRX)
     {
         if ((bottomBandLimit<=freqTX) && (freqTX<= upperBandLimit))
         {
+            logEvent (Q_FUNC_INFO, "END-3", Debug);
             return true;
         }
         //qDebug() << Q_FUNC_INFO << ": Freq is not in the current band" << QT_ENDL;
@@ -569,25 +600,29 @@ bool MainQSOEntryWidget::setFreq(const double _f, bool isRX)
         if (isRX)
         {
             //qDebug() << Q_FUNC_INFO << ": RX Freq no more actions "  << QT_ENDL;
+            logEvent (Q_FUNC_INFO, "END-4", Debug);
             return true;
         }
+        logEvent (Q_FUNC_INFO, "END-5", Debug);
         return setBand(_newBand);
     }
+    logEvent (Q_FUNC_INFO, "END", Debug);
     return false;
 }
 
 bool MainQSOEntryWidget::newBandNeededForFreq(const double _f)
 {
     //qDebug() << Q_FUNC_INFO << ": " << QString::number(_f);
+    logEvent (Q_FUNC_INFO, "Start: " + QString::number(_f), Debug);
     QString _newBand = dataProxy->getBandNameFromFreq(_f);
     if (!updateBandComboBox (_newBand))
     {
-        emit debugLog(Q_FUNC_INFO, "END-1", Debug);
+        logEvent (Q_FUNC_INFO, "END-1", Debug);
         //qDebug() << Q_FUNC_INFO << " - END false";
         return false;
     }
     //qDebug() << Q_FUNC_INFO << " - END true ";
-    emit debugLog(Q_FUNC_INFO, "END", Debug);
+    logEvent (Q_FUNC_INFO, "END", Debug);
     return true;
 }
 
@@ -595,99 +630,105 @@ bool MainQSOEntryWidget::setBand(const QString &_band)
 {
     //qDebug() << Q_FUNC_INFO << ": " << _band << QT_ENDL;
 
-    emit debugLog(Q_FUNC_INFO, "Start", Debug);
+    logEvent (Q_FUNC_INFO, "Start: " + _band, Debug);
     if (bandComboBox->findText(_band, Qt::MatchCaseSensitive) < 0)
     {
         //qDebug() << "MainQSOEntryWidget::setBand-1: Band not found " << _band << QT_ENDL;
         if (!updateBandComboBox(_band))
         {
-            emit debugLog(Q_FUNC_INFO, "END-1", Debug);
+            logEvent (Q_FUNC_INFO, "END-1", Debug);
             return false;
         }
     }
     //qDebug() << "MainQSOEntryWidget::setBand-1: Band found " << _band << QT_ENDL;
     bandComboBox->setCurrentIndex(bandComboBox->findText(_band, Qt::MatchCaseSensitive));
-    emit debugLog(Q_FUNC_INFO, "END-2", Debug);
-    //qDebug() << Q_FUNC_INFO << " - END"  << QT_ENDL;
+    logEvent (Q_FUNC_INFO, "END", Debug);
     return true;
 }
 
 bool MainQSOEntryWidget::setMode(const QString &_mode)
 {
-    emit debugLog(Q_FUNC_INFO, "Start", Debug);
+    logEvent (Q_FUNC_INFO, "Start" + _mode, Debug);
     //qDebug() << "MainQSOEntryWidget::setMode: " << _mode;
     if (modeComboBox->findText(_mode, Qt::MatchCaseSensitive) < 0)
     {
         //qDebug() << "MainQSOEntryWidget::setMode NOT found";
-        emit debugLog(Q_FUNC_INFO, "END-1", Debug);
+        logEvent (Q_FUNC_INFO, "END-1", Debug);
         return false;
     }
     else
     {
         //qDebug() << "MainQSOEntryWidget::setMode Updated";
         modeComboBox->setCurrentIndex(modeComboBox->findText(_mode, Qt::MatchCaseSensitive));
-        emit debugLog(Q_FUNC_INFO, "END", Debug);
+        logEvent (Q_FUNC_INFO, "END-2", Debug);
         return true;
     }
 }
 
 bool MainQSOEntryWidget::setQRZ(const QString &_qrz)
 {
-    emit debugLog(Q_FUNC_INFO, "Start", Debug);
+    logEvent (Q_FUNC_INFO, "Start", Debug);
     //qDebug() << "MainQSOEntryWidget::setQRZ: " << _qrz << QT_ENDL;
     //TODO: Add validations to prevent that non valid qrz are sent from the outside of this function or at least manage this appropriately.
     qrzLineEdit->setText(_qrz.toUpper());
-    emit debugLog(Q_FUNC_INFO, "END", Debug);
+    logEvent (Q_FUNC_INFO, "END", Debug);
     return false;
 }
 
 bool MainQSOEntryWidget::setDateTime(const QDateTime _date)
 {
-    emit debugLog(Q_FUNC_INFO, "Start", Debug);
+    logEvent (Q_FUNC_INFO, "Start", Debug);
     if (_date.isValid())
     {
         dateEdit->setDate(_date.date());
         timeEdit->setTime(_date.time());
-        emit debugLog(Q_FUNC_INFO, "END", Debug);
+        logEvent (Q_FUNC_INFO, "END-1", Debug);
         return true;
     }
     else
     {
         //qDebug() << "MainQSOEntryWidget::setDate - NO VALID DATE" << QT_ENDL;
-        emit debugLog(Q_FUNC_INFO, "END", Debug);
+        logEvent (Q_FUNC_INFO, "END-2", Debug);
         return false;
     }
 }
 
 bool MainQSOEntryWidget::setTime(const QTime _time)
 {
-    emit debugLog(Q_FUNC_INFO, "Start", Debug);
+    logEvent (Q_FUNC_INFO, "Start", Debug);
     if (_time.isValid())
     {
         timeEdit->setTime(_time);
-        emit debugLog(Q_FUNC_INFO, "END", Debug);
+        logEvent (Q_FUNC_INFO, "END-1", Debug);
         return true;
     }
     else
     {
-        emit debugLog(Q_FUNC_INFO, "END", Debug);
+        logEvent (Q_FUNC_INFO, "END-2", Debug);
         return false;
     }
 }
 
 QString MainQSOEntryWidget::getQrz()
 {
-    emit debugLog(Q_FUNC_INFO, "Start", Debug);
-    emit debugLog(Q_FUNC_INFO, "END", Debug);
-    return (qrzLineEdit->text()).toUpper();
+    logEvent (Q_FUNC_INFO, "Start", Debug);
+    QString aux;
+    aux = qrzLineEdit->text();
+    if(aux.length()<1)
+    {
+        logEvent(Q_FUNC_INFO, "END - Not valid", Debug);
+        return QString();
+    }
+    logEvent(Q_FUNC_INFO, "END", Debug);
+    return aux.toUpper();
 }
 
 QString MainQSOEntryWidget::getBand(const int _b)
 {
-    emit debugLog(Q_FUNC_INFO, "Start", Debug);
+    logEvent (Q_FUNC_INFO, "Start: " + QString::number(_b), Debug);
     if (_b<0)
     {
-        emit debugLog(Q_FUNC_INFO, "END", Debug);
+        logEvent (Q_FUNC_INFO, "END-1", Debug);
         //qDebug() << "MainQSOEntryWidget::getBand(1): " << bandComboBox->currentText()<< QT_ENDL;
         return bandComboBox->currentText();
     }
@@ -695,37 +736,37 @@ QString MainQSOEntryWidget::getBand(const int _b)
     {
         if (bandComboBox->count()>=_b)
         {
-            emit debugLog(Q_FUNC_INFO, "END-1", Debug);
+            logEvent (Q_FUNC_INFO, "END-2", Debug);
             //qDebug() << "MainQSOEntryWidget::getBand(2): " << bandComboBox->currentText()<< QT_ENDL;
             return bandComboBox->itemText(_b);
         }
         else
         {
-            emit debugLog(Q_FUNC_INFO, "END-2", Debug);
+            logEvent (Q_FUNC_INFO, "END-3", Debug);
             //qDebug() << "MainQSOEntryWidget::getBand(3): " << bandComboBox->currentText()<< QT_ENDL;
             return bandComboBox->currentText();
         }
     }
 }
 
-QString MainQSOEntryWidget::getMode(const int _m)
+QString MainQSOEntryWidget::getMode(int _m)
 {
-    emit debugLog(Q_FUNC_INFO, "Start", Debug);
+    logEvent (Q_FUNC_INFO, "Start: " + QString::number(_m), Debug);
     if (_m<0)
     {
-        emit debugLog(Q_FUNC_INFO, "END", Debug);
+        logEvent (Q_FUNC_INFO, "END-1", Debug);
         return modeComboBox->currentText();
     }
     else
     {
         if (modeComboBox->count()>=_m)
         {
-            emit debugLog(Q_FUNC_INFO, "END-1", Debug);
+            logEvent (Q_FUNC_INFO, "END-2", Debug);
             return modeComboBox->itemText(_m);
         }
         else
         {
-            emit debugLog(Q_FUNC_INFO, "END-2", Debug);
+            logEvent (Q_FUNC_INFO, "END-3", Debug);
             return modeComboBox->currentText();
         }
     }
@@ -733,32 +774,31 @@ QString MainQSOEntryWidget::getMode(const int _m)
 
 QDate MainQSOEntryWidget::getDate()
 {
-    emit debugLog(Q_FUNC_INFO, "Start", Debug);
-    emit debugLog(Q_FUNC_INFO, "END", Debug);
+    logEvent (Q_FUNC_INFO, "Start-End", Debug);
     return dateEdit->date();
 }
 
 
 QDateTime MainQSOEntryWidget::getDateTime()
 {
-    emit debugLog(Q_FUNC_INFO, "Start", Debug);
-    //emit debugLog(Q_FUNC_INFO, "END", Debug);
+    logEvent (Q_FUNC_INFO, "Start", Debug);
+    //logEvent (Q_FUNC_INFO, "END", Debug);
     QDateTime dateTime;
     dateTime.setDate(dateEdit->date());
     dateTime.setTime(timeEdit->time());
+    logEvent (Q_FUNC_INFO, "END", Debug);
     return dateTime;
 }
 
 QTime MainQSOEntryWidget::getTime()
 {
-    emit debugLog(Q_FUNC_INFO, "Start", Debug);
-    emit debugLog(Q_FUNC_INFO, "END", Debug);
+    logEvent (Q_FUNC_INFO, "Start-End", Debug);
     return timeEdit->time();
 }
 
 void MainQSOEntryWidget::toggleRealTime()
 {
-    //if ( realtimeButton->isChecked ())
+    logEvent (Q_FUNC_INFO, "Start", Debug);
     if ( realtimeCheckBox->isChecked ())
     {
         setRealTime (false);
@@ -767,49 +807,50 @@ void MainQSOEntryWidget::toggleRealTime()
     {
         setRealTime (true);
     }
+    logEvent (Q_FUNC_INFO, "END", Debug);
 }
 
 bool MainQSOEntryWidget::getRealTime()
 {
-    //return realtimeButton->isChecked ();
+    logEvent (Q_FUNC_INFO, "Start-End", Debug);
     return realtimeCheckBox->isChecked ();
 }
 
 void MainQSOEntryWidget::setRealTime(const bool _realTime)
 {
-    emit debugLog(Q_FUNC_INFO, "Start", Debug);
+    logEvent (Q_FUNC_INFO, "Start", Debug);
     //qDebug << Q_FUNC_INFO << ": " << util->boolToQString (_realTime);
 
     realTime = _realTime;
     realtimeCheckBox->setChecked(realTime);
-    emit debugLog(Q_FUNC_INFO, "END", Debug);
+    logEvent (Q_FUNC_INFO, "END", Debug);
 }
 
 void MainQSOEntryWidget::setManualMode(const bool _manualMode)
 {
-    emit debugLog(Q_FUNC_INFO, "Start", Debug);
+    logEvent (Q_FUNC_INFO, "Start", Debug);
     manualModeCheckBox->setChecked (_manualMode);
-    emit debugLog(Q_FUNC_INFO, "END", Debug);
+    logEvent (Q_FUNC_INFO, "END", Debug);
 }
 
 bool MainQSOEntryWidget::getManualMode()
 {
-    emit debugLog(Q_FUNC_INFO, "Start", Debug);
+    logEvent (Q_FUNC_INFO, "Start-End", Debug);
     return manualModeCheckBox->isChecked ();
-    emit debugLog(Q_FUNC_INFO, "END", Debug);
+    //logEvent (Q_FUNC_INFO, "END", Debug);
 }
 
 void MainQSOEntryWidget::setUTC(const bool _utc)
 {
-    emit debugLog(Q_FUNC_INFO, "Start", Debug);
+    logEvent (Q_FUNC_INFO, "Start", Debug);
     UTCTime = _utc;
     setDateAndTimeInternally();
-    emit debugLog(Q_FUNC_INFO, "END", Debug);
+    logEvent (Q_FUNC_INFO, "END", Debug);
 }
 
 void MainQSOEntryWidget::setModify(const bool _modify)
 {
-    emit debugLog(Q_FUNC_INFO, "Start", Debug);
+    logEvent (Q_FUNC_INFO, "Start", Debug);
     modify = _modify;
     if (modify)
     {
@@ -822,31 +863,29 @@ void MainQSOEntryWidget::setModify(const bool _modify)
         OKButton->setText(tr("&Add"));
         clearButton->setText(tr("&Clear"));
     }
-    emit debugLog(Q_FUNC_INFO, "END", Debug);
+    logEvent (Q_FUNC_INFO, "END", Debug);
 }
 
 bool MainQSOEntryWidget::getModifying()
 {
+    logEvent (Q_FUNC_INFO, "Start-End", Debug);
     return modify;
 }
 
 void MainQSOEntryWidget::slotUpdateTime()
 {
-    //qDebug()<< "MainQSOEntryWidget::slotUpdateTime" << QT_ENDL;
-    //emit debugLog(Q_FUNC_INFO, "Start", Debug);
-
-    //if ( (!modify) && (realtimeButton->isChecked())  )
+    //logEvent (Q_FUNC_INFO, "Start", Debug);
     if ( (!modify) && (realtimeCheckBox->isChecked())  )
     {
         //qDebug()<< "MainQSOEntryWidget::slotUpdateTime - Real Time & update" << QT_ENDL;
         setDateAndTimeInternally();
     }
-
-    //emit debugLog(Q_FUNC_INFO, "END", Debug);
+    //logEvent (Q_FUNC_INFO, "END", Debug);
 }
 
 void MainQSOEntryWidget::setDateAndTimeInternally()
 {
+    //logEvent (Q_FUNC_INFO, "Start", Debug);
     if (UTCTime)
     {
         dateEdit->setDate(QDateTime::currentDateTime().toUTC().date());
@@ -857,52 +896,53 @@ void MainQSOEntryWidget::setDateAndTimeInternally()
         dateEdit->setDate(QDateTime::currentDateTime().date());
         timeEdit->setTime(QDateTime::currentDateTime().time());
     }
+    //logEvent (Q_FUNC_INFO, "END", Debug);
 }
 
 bool MainQSOEntryWidget::validCharactersInCall(const QString &_qrz)
 {
     //qDebug()<< "MainQSOEntryWidget::validCharactersInCall: " << _qrz << QT_ENDL;
-    emit debugLog(Q_FUNC_INFO, "Start", Debug);
+    logEvent (Q_FUNC_INFO, "Start", Debug);
     for (int i = 0; i<_qrz.size()-1;i++)
     {
         if (!( ((_qrz.at(i)).isLetterOrNumber()) || (_qrz.at(i)=='\\')  || (_qrz.at(i)=='/')  ))
         {
-            emit debugLog(Q_FUNC_INFO, "END-1", Debug);
+            logEvent (Q_FUNC_INFO, "END-1", Debug);
             return false;
         }
     }
-    emit debugLog(Q_FUNC_INFO, "END", Debug);
+    logEvent (Q_FUNC_INFO, "END", Debug);
     return true;
 }
 
 bool MainQSOEntryWidget::isModeExisting(const QString &_m)
 {
-    emit debugLog(Q_FUNC_INFO, "Start", Debug);
+    logEvent (Q_FUNC_INFO, "Start", Debug);
     if (modeComboBox->findText(_m, Qt::MatchCaseSensitive) >= 0)
     {
-        emit debugLog(Q_FUNC_INFO, "END-1", Debug);
+        logEvent (Q_FUNC_INFO, "END-1", Debug);
         return true;
     }
     else
     {
-        emit debugLog(Q_FUNC_INFO, "END-2", Debug);
+        logEvent (Q_FUNC_INFO, "END-2", Debug);
         return false;
     }
 }
 
 bool MainQSOEntryWidget::isBandExisting(const QString &_b)
 {
-    emit debugLog(Q_FUNC_INFO, "Start", Debug);
+    logEvent (Q_FUNC_INFO, "Start", Debug);
     //qDebug() << Q_FUNC_INFO << ": " << _b << QT_ENDL;
     if (bandComboBox->findText(_b, Qt::MatchCaseSensitive) >= 0)
     {
-        emit debugLog(Q_FUNC_INFO, "END-1", Debug);
+        logEvent (Q_FUNC_INFO, "END-1", Debug);
         //qDebug() << Q_FUNC_INFO << " - END true" << QT_ENDL;
         return true;
     }
     else
     {
-        emit debugLog(Q_FUNC_INFO, "END-2", Debug);
+        logEvent (Q_FUNC_INFO, "END-2", Debug);
         //qDebug() << Q_FUNC_INFO << " - END false" << QT_ENDL;
         return false;
     }
@@ -910,18 +950,18 @@ bool MainQSOEntryWidget::isBandExisting(const QString &_b)
 
 void MainQSOEntryWidget::setUpAndRunning(const bool _u)
 {
-    emit debugLog(Q_FUNC_INFO, "Start", Debug);
+    logEvent (Q_FUNC_INFO, "Start", Debug);
     upAndRunning = _u;
-    emit debugLog(Q_FUNC_INFO, "END", Debug);
+    logEvent (Q_FUNC_INFO, "END", Debug);
 }
 
-void MainQSOEntryWidget::selectDefaultBand(const bool _init)
+void MainQSOEntryWidget::selectDefaultBand(bool _init)
 {
       //qDebug() << "MainQSOEntryWidget::selectDefaultBand" << QT_ENDL;
-    emit debugLog(Q_FUNC_INFO, "Start", Debug);
+    logEvent (Q_FUNC_INFO, "Start", Debug);
     if ((upAndRunning) || (!_init))
     {
-        emit debugLog(Q_FUNC_INFO, "END-1", Debug);
+        logEvent (Q_FUNC_INFO, "END-1", Debug);
           //qDebug() << "MainQSOEntryWidgetselectDefaultBand-END-1" << QT_ENDL;
         return;
     }
@@ -937,17 +977,15 @@ void MainQSOEntryWidget::selectDefaultBand(const bool _init)
     aux = dataProxy->getNameFromBandId(defaultBand);
     //qDebug() << Q_FUNC_INFO << ": before setting band: " << aux << QT_ENDL;
     setBand(aux);
-    emit debugLog(Q_FUNC_INFO, "END", Debug);
-      //qDebug() << "MainQSOEntryWidgetselectDefaultBand_END" << QT_ENDL;
+    logEvent (Q_FUNC_INFO, "END", Debug);
 }
 
-void MainQSOEntryWidget::selectDefaultMode(const bool _init)
+void MainQSOEntryWidget::selectDefaultMode(bool _init)
 {
-      //qDebug() << "MainQSOEntryWidgetselectDefaultMode" << QT_ENDL;
-    emit debugLog(Q_FUNC_INFO, "Start", Debug);
+    logEvent (Q_FUNC_INFO, "Start", Debug);
     if ((upAndRunning) || (!_init))
     {
-        emit debugLog(Q_FUNC_INFO, "END-1", Debug);
+        logEvent (Q_FUNC_INFO, "END-1", Debug);
         return;
     }
     int defaultMode = dataProxy->getMostUsedMode(-1); //TODO: The log could be defined here
@@ -961,16 +999,18 @@ void MainQSOEntryWidget::selectDefaultMode(const bool _init)
     //modeComboBox->setCurrentIndex(modeComboBox->findText(dataProxy->getNameFromSubModeId(defaultMode)));
 
      //qDebug() << "MainQSOEntryWidgetselectDefaultMode3: " << QString::number(defaultMode) << QT_ENDL;
-    emit debugLog(Q_FUNC_INFO, "END", Debug);
+    logEvent (Q_FUNC_INFO, "END", Debug);
      //qDebug() << "MainQSOEntryWidgetselectDefaultMode-END" << QT_ENDL;
 }
 
 void MainQSOEntryWidget::setDuplicatedQSOSlot (const int _secs)
 {
+    logEvent (Q_FUNC_INFO, "Start", Debug);
     if (_secs >= 0)
     {
         duplicatedQSOSlotInSecs = _secs;
     }
+    logEvent (Q_FUNC_INFO, "END", Debug);
 }
 
 void MainQSOEntryWidget::checkIfDupe(const QString &_func)
@@ -979,7 +1019,7 @@ void MainQSOEntryWidget::checkIfDupe(const QString &_func)
    //qDebug() << Q_FUNC_INFO << "(" << _func << ")" << QT_ENDL;
 #else
 #endif
-
+    logEvent (Q_FUNC_INFO, "Start", Debug);
     QDateTime _dateTime;
     _dateTime.setDate(dateEdit->date());
     _dateTime.setTime(timeEdit->time());
@@ -995,18 +1035,22 @@ void MainQSOEntryWidget::checkIfDupe(const QString &_func)
         //qDebug() << Q_FUNC_INFO << " - NOT DUPE " << QT_ENDL;
         qrzgroupBox->setTitle(tr("DUPE", "Translator: DUPE is a common world for hams. Do not translate of not sure"));
     }
+    logEvent (Q_FUNC_INFO, "END", Debug);
 }
 
 void MainQSOEntryWidget::slotStartDelayInputTimer()
 {
+    logEvent (Q_FUNC_INFO, "Start", Debug);
     if (cleaning)
     {
+        logEvent (Q_FUNC_INFO, "END-1", Debug);
         return;
     }
     if (qrzLineEdit->text ().length ()<1)
     {
         //qDebug() << Q_FUNC_INFO;
         slotClearButtonClicked ();
+        logEvent (Q_FUNC_INFO, "END-2", Debug);
         return;
     }
 
@@ -1015,21 +1059,26 @@ void MainQSOEntryWidget::slotStartDelayInputTimer()
     qrzLineEdit->setText (aux.toUpper());
     qrzLineEdit->setCursorPosition (cursor);
     delayInputTimer->start(300);
+    logEvent (Q_FUNC_INFO, "END", Debug);
 }
 
 void MainQSOEntryWidget::slotDelayInputTimedOut()
 {
+    logEvent (Q_FUNC_INFO, "Start", Debug);
     delayInputTimer->stop();
     QString text = qrzLineEdit->text();
     if( text != lastQrz)
     {
+        //qDebug() << Q_FUNC_INFO << ": going for slotQRZTextChanged";
         text = lastQrz;
         slotQRZTextChanged();
     }
+    logEvent (Q_FUNC_INFO, "END", Debug);
 }
 
 bool MainQSOEntryWidget::getDarkMode()
 {
+    logEvent (Q_FUNC_INFO, "Start-End", Debug);
     return (OKButton->palette().color (QPalette::Base) == "#646464");
 }
 
@@ -1041,12 +1090,12 @@ void MainQSOEntryWidget::keyPressEvent( QKeyEvent *event)
     {
         //qDebug() << Q_FUNC_INFO << " TAB...";
     }
-
 }
 */
 
 bool MainQSOEntryWidget::eventFilter(QObject *object, QEvent *event)
 {
+    logEvent (Q_FUNC_INFO, "Start", Debug);
     if (!(event->type() == QEvent::Paint ))
     {
         //qDebug() << Q_FUNC_INFO << ": " << QString::number(event->type ());
@@ -1068,15 +1117,34 @@ bool MainQSOEntryWidget::eventFilter(QObject *object, QEvent *event)
                 //qDebug() << Q_FUNC_INFO << "emitting to hand over to QSO TAB-2";
                 emit handOverFocusSignal();
             }
-
             // special tab handling here
+            logEvent (Q_FUNC_INFO, "END-1", Debug);
             return true;
         }
     }
+    logEvent (Q_FUNC_INFO, "END", Debug);
     return QWidget::event(event);
 }
 
 void MainQSOEntryWidget::setFocusToOK()
 {
+    logEvent (Q_FUNC_INFO, "Start", Debug);
     OKButton->setFocus ();
+    logEvent (Q_FUNC_INFO, "END", Debug);
+}
+
+void MainQSOEntryWidget::slotCaptureDebugLogs(const QString &_func, const QString &_msg, DebugLogLevel _level)
+{
+    //qDebug() << Q_FUNC_INFO << _func << "/" << _msg << "/" << QString::number(_level);
+    logEvent(_func, _msg, _level);
+}
+
+void MainQSOEntryWidget::logEvent(const QString &_func, const QString &_msg, DebugLogLevel _level)
+{
+    //qDebug() << Q_FUNC_INFO;
+    if (logLevel<=_level)
+    {
+        //qDebug() << Q_FUNC_INFO << "Emitting...";
+        emit debugLog (_func, _msg, _level);
+    }
 }
