@@ -30,11 +30,12 @@
 #include <QtWidgets>
 #include "dataproxy_sqlite.h"
 #include "utilities.h"
-//#include "hamlibclass.h"
 
 class MainQSOEntryWidget : public QWidget
 {
     Q_OBJECT
+    friend class tst_MainWindow;
+
 public:
     explicit MainQSOEntryWidget(DataProxy_SQLite *dp, QWidget *parent = nullptr);
     ~MainQSOEntryWidget();
@@ -52,10 +53,10 @@ public:
     void setCleaning (const bool _c);
     bool isModeExisting(const QString &_m);
     bool isBandExisting(const QString &_b);
-
+    void setShowSeconds(const bool &t);
     QString getQrz();
-    QString getBand(const int _b=-1);
-    QString getMode(const int _m=-1);
+    QString getBand(int _b=-1);
+    QString getMode(int _m=-1);
     QStringList getModes();
     QDate getDate();
     QTime getTime();
@@ -71,11 +72,13 @@ public:
     void setModify(const bool _modify);
     bool getModifying();
     void setUpAndRunning(const bool _u);
-    void selectDefaultBand(const bool _init = false);
-    void selectDefaultMode(const bool _init = false);
+    void selectDefaultBand(bool _init = false);
+    void selectDefaultMode(bool _init = false);
 
     void setDuplicatedQSOSlot (const int _secs);
     void setFocusToOK();
+    void setLogLevel (const DebugLogLevel _b);
+    void setCallValidation (const bool _b);
     void clear();
 
 protected:
@@ -95,6 +98,7 @@ signals:
     void manualModeSignal(bool _active);
 
 private slots:
+    void slotCaptureDebugLogs(const QString &_func, const QString &_msg, DebugLogLevel _level);
     void slotUpdateTime();
     void slotQRZTextChanged();
     void slotBandComboBoxChanged(const QString &_b);
@@ -109,8 +113,8 @@ private slots:
     //void slotRealTimeButtonResize();
     void slotManualModeCheckBoxClicked();
 
-
 private:
+    void logEvent(const QString &_func, const QString &_msg, DebugLogLevel _level);
     bool eventFilter(QObject *object, QEvent *event);
     void createUI();
     void setInitialData();
@@ -130,7 +134,7 @@ private:
     QPushButton *OKButton, *clearButton;
     QCheckBox *realtimeCheckBox, *manualModeCheckBox;
     //QPushButton *realtimeButton;
-    //DebugLogLevel logSeverity;
+    //DebugLogLevel logLevel;
     bool cleaning;
     bool qrzAutoChanging;
     bool InValidCharsInPrevCall;
@@ -154,7 +158,7 @@ private:
     QTimer *delayInputTimer;
     QString lastQrz;
     double freqTX, freqRX, bottomBandLimit, upperBandLimit;
-
+    DebugLogLevel logLevel;
     //HamLibClass *hamlib;
 };
 
