@@ -29,25 +29,18 @@
 #include <QtWidgets>
 #include <QPrinter>
 #include <QPrintDialog>
-
 #include <QNetworkRequest>
 #include <QNetworkReply>
 #include <QtAlgorithms>
 #include <QDesktopServices>
 #include <QUrl>
 
-//#include "database.h"
 #include "setupdialog.h"
-#include "setuppages/setuppagemisc.h"
-//#include "helpaboutdialog.h"
 #include "aboutdialog.h"
-//#include "dxccsummarydialog.h"
 #include "tipsdialog.h"
 #include "world.h"
 #include "filemanager.h"
 #include "fileawardmanager.h"
-//#include "contest.h"
-//#include "contest_cqwwdxssb.h"
 #include "dataproxy_sqlite.h"
 #include "dataproxy_sqlite.h"
 #include "locator.h"
@@ -67,7 +60,6 @@
 #include "dxccstatuswidget.h"
 #include "awardswidget.h"
 #include "softwareupdate.h"
-#include "logmodel.h"
 #include "logwindow.h"
 #include "searchwidget.h"
 #include "infowidget.h"
@@ -77,12 +69,10 @@
 #include "updatesatsdata.h"
 #include "hamlibclass.h"
 #include "elogqrzlog.h"
-//#include "pstrotatorsupport.h"
 #include "lotwutilities.h"
 #include "eqslutilities.h"
 #include "widgets/adiflotwexportwidget.h"
 #include "widgets/showadifimportwidget.h"
-//#include "widgets/advancedsearch/advancedsearchwidget.h"
 #include "widgets/map/mapwindowwidget.h"
 #include "widgets/showkloglogwidget.h"
 #include "qso.h"
@@ -140,6 +130,7 @@ enum
 class MainWindow : public  QMainWindow
 {
     Q_OBJECT
+    friend class tst_MainWindow;
 
 public:
     MainWindow(const QString &_klogDir, const QString &tversion);
@@ -147,6 +138,7 @@ public:
     void checkIfNewVersion();
     void recommendBackupIfNeeded();
     void init();
+    void showNotWar();
 
 private slots:
     //void slotQueryErrorManagement(QString functionFailed, QString errorCodeS, QString nativeError, QString failedQuery);
@@ -322,14 +314,15 @@ private slots:
                      const QString &_opCall, const QDateTime &_datetime, const QDateTime &_datetime_off,
                      const QString &_exchangeTX, const QString &_exchangeRX, const QString &_mypwr);
 
-    void slotCaptureDebugLogs(const QString &_func, const QString &_msg, DebugLogLevel _level=Info);
+    void slotCaptureDebugLogs(const QString &_func, const QString &_msg, DebugLogLevel _level);
     //void slotTakeOverFocus(int _id);
     void slotTakeOverFocusToQSOTabWidget();
     void slotTakeOverFocusToMainQSOInput();
+    void slotNewLogLevel(DebugLogLevel l);
 
 private:
     //void setWidgetsOrder();
-    void showNotWar();
+
     void startServices();
     void backupCurrentQSO();
     void restoreCurrentQSO(const bool restoreConfig);
@@ -341,8 +334,8 @@ private:
     void setCleaning(const bool _c);
     bool setHamlib(const bool _b);
     bool setUDPServer(const bool _b);
-    void logEvent(const QString &_func, const QString &_msg, const DebugLogLevel _level=Info);
-    void setSeverity(const DebugLogLevel _sev);
+    void logEvent(const QString &_func, const QString &_msg, DebugLogLevel _level);
+    void setLogLevel(const DebugLogLevel _sev);
     void fileExportLoTW(const QString &_st, const QDate &_startDate, const QDate &_endDate);
     void fileExportClubLog(const QString &_st, const QDate &_startDate, const QDate &_endDate);
     void fileExportEQSL(const QString &_st, const QDate &_startDate, const QDate &_endDate);
@@ -451,7 +444,7 @@ private:
     Locator *locator;
     Awards *awards;
     Utilities *util;
-    SetupPageMisc *miscPage;
+    //SetupPageMisc *miscPage;
 
 
     //WorldEditorWidget *worldEditor;
@@ -461,37 +454,18 @@ private:
     AboutDialog *aboutDialog;
     TipsDialog *tipsDialog;
     ShowKLogLogWidget * showKLogLogWidget;
-    //DXCCSummaryDialog *dxccSummaryDialog;
-
-
-    //QPushButton *addButton;
-    //QLabel *distShortLabelN;
-    //QLabel *distLongLabelN;
     StatisticsWidget *statsWidget;
     DXCCStatusWidget *dxccStatusWidget;
-    //QSqlRelationalTableModel *logModel;
-    //QWidget *logPanel;
-    //QTableView *logView;
-    //QTreeWidget *searchResultsTreeWidget;
     QLabel *logLabel;
 
-    //QWidget *scoreWindow; //, dxWindow;
-    //QTextEdit *scoreTextEdit;
-
-    LogModel *logModel;
+    //LogModel *logModel;
     LogWindow *logWindow;
     UDPServer *UDPLogServer;
 
     ShowErrorDialog *showErrorDialog;
 
     // <UI>
-    //QGroupBox *gridGroupBox;//, *qrzgroupBox;//, *searchgroupBox;
     QFrame *dxUpLeftInputFrame;//, *dxUpRightOutputFrame;
-
-    //QComboBox *bandComboBox, *modeComboBox;
-    //QDateEdit *dateEdit;
-    //QTimeEdit *timeEdit;
-    //QStatusBar *statusBar, *qsoStatusBar;
     QString statusBarMessage;
 
     QTabWidget *dxBottonTab, *dxUpLeftTab, *dxUpRightTab;
@@ -592,9 +566,8 @@ private:
 
     bool checkNewVersions, reportInfo; // Selected in the Setup->Misc to check if new versions and report info back to KLog's servers
     bool logEvents;                     // Should KLog log the events for debugging
-    bool debugFileOpen;                 //Is the debugFile open?
-    QFile *debugFile;
-    DebugLogLevel logSeverity;    // Manages as syslog, the severity of the application debug log (7 means debug, 0 emergency)
+
+    DebugLogLevel logLevel;    // Manages as syslog, the severity of the application debug log (7 means debug, 0 emergency)
 
     bool txFreqBeingChanged,  updatingBands; //rxFreqBeingChanged  // When the freqs is being modified it is defined to true to prevent other automated to change.
     bool txFreqBeingAutoChanged, rxFreqBeingAutoChanged;        // This is defined to true when freq is being changed by the Sat tab to prevent a loop.
@@ -654,8 +627,8 @@ private:
     QString mainQRZ, stationCallsign, operatorQRZ, dxLocator;
 
     double myPower, lastPower;
-
-    int my_CQz, my_ITUz, defaultMode, defaultBand, currentMode, currentModeShown, currentBand, currentBandShown;
+    //int my_CQz, my_ITUz; Not used
+    int defaultMode, defaultBand, currentMode, currentModeShown, currentBand, currentBandShown;
     int currentEntity, previousEntity;
     bool InValidCharsInPrevCall;
     int currentLog; // This is to be able to manage multiple logs without showing
