@@ -36,8 +36,11 @@ SearchWidget::SearchWidget(DataProxy_SQLite *dp, QWidget *parent) :
     searchWindow = new SearchWindow(dataProxy, this);
 
     awards = new Awards(dataProxy, Q_FUNC_INFO);
-    util = new Utilities;
+    util = new Utilities(Q_FUNC_INFO);
+    util->setLongPrefixes(dataProxy->getLongPrefixes());
+    util->setSpecialCalls(dataProxy->getSpecialCallsigns());
     filemanager = new FileManager(dataProxy);
+    filemanager->init();
 
     world = new World(dataProxy, Q_FUNC_INFO);
     mainStationCallsign = QString();
