@@ -35,7 +35,7 @@ SearchWindow::SearchWindow(DataProxy_SQLite *dp, QWidget *parent) : QWidget(pare
     showStationCallsignInHeader = true;
     //sortingThroughProxyModel = false;
     searchModel = new SearchModel(dataProxy, this);
-    util = new Utilities;
+    util = new Utilities(Q_FUNC_INFO);
     connect(searchModel, SIGNAL(queryError(QString, QString, QString, QString)), this, SLOT(slotQueryErrorManagement(QString, QString, QString, QString)) );
     //logView = new QTableView;
     treeView = new QTreeView;
@@ -58,6 +58,7 @@ SearchWindow::~SearchWindow()
 //    emit clearError();
     delete(dataProxy);
     delete(util);
+    delete(awards);
 }
 
 
@@ -285,10 +286,7 @@ void SearchWindow::rightButtonFromLogMenu(const int row)
     checkDXHeatFromLogAct->setData(row);
 
         menu.addSeparator();
-        if (qslSent)
-        {
-        }
-        else
+        if (!qslSent)
         {
             QMenu *menuSentQsl = menu.addMenu(tr("QSL Send"));
             menuSentQsl->addAction(qslSentViaBureauFromLogAct);
@@ -306,10 +304,7 @@ void SearchWindow::rightButtonFromLogMenu(const int row)
             qslSentRequestedAct->setData(row);
            }
 
-        if (qslReceived)
-        {
-        }
-        else
+        if (!qslReceived)
         {
             QMenu *menuRecQsl = menu.addMenu(tr("QSL Rcvd"));
             menuRecQsl->addAction(qslRecViaBureauFromLogAct);
