@@ -25,7 +25,6 @@
  *****************************************************************************/
 
 #include "setupdialog.h"
-#include "setuppages/setuppagemisc.h"
 //#include <QDebug>
 
 /*
@@ -33,19 +32,22 @@ This class calls all the othet "Setup..." to manage the configuration
 
 */
 
-SetupDialog::SetupDialog(DataProxy_SQLite *dp, const QString &_configFile, const QString &_softwareVersion, const int _page, const bool _firstTime, QWidget *parent)
+SetupDialog::SetupDialog(DataProxy_SQLite *dp, QWidget *parent)
 {
     //qDebug() << Q_FUNC_INFO << ": " << _configFile << "/" << _softwareVersion << "/" << QString::number(_page) << util->boolToQString(_firstTime);
 
-    logSeverity = Info;
+    logLevel = None;
     constrid = 2;
-    util = new Utilities;
-    firstTime = _firstTime;
+    nolog = true;
+    util = new Utilities(Q_FUNC_INFO);
+    firstTime = true;
     latestBackup = QString();
     dataProxy = dp;
-    configFileName = _configFile;
-    version = _softwareVersion;
-    pageRequested = _page;
+
+    configFileName = QString();
+    version = QString();
+    pageRequested = 0;
+
     int logsPageTabN=-1;
     //qDebug() << Q_FUNC_INFO << ": 01" << QT_ENDL;
 
@@ -93,7 +95,7 @@ SetupDialog::SetupDialog(DataProxy_SQLite *dp, const QString &_configFile, const
     tabWidget->addTab(hamlibPage, tr ("HamLib"));
     //qDebug() << "SetupDialog::SetupDialog 03" << QT_ENDL;
 
-    QPushButton *closeButton = new QPushButton(tr("Cancel"));
+    closeButton = new QPushButton(tr("Cancel"));
     okButton = new QPushButton(tr("OK"));
 
     QHBoxLayout *horizontalLayout = new QHBoxLayout;
@@ -113,7 +115,18 @@ SetupDialog::SetupDialog(DataProxy_SQLite *dp, const QString &_configFile, const
     setLayout(mainLayout);
     setWindowTitle(tr("Settings"));
 
-    //qDebug() << Q_FUNC_INFO << ": 05" << QT_ENDL;
+    //connectActions();
+    //qDebug() << Q_FUNC_INFO << " - END" << QT_ENDL;
+}
+
+void SetupDialog::init(const QString &_configFile, const QString &_softwareVersion, const int _page, const bool _firstTime)
+{
+    util->setLongPrefixes(dataProxy->getLongPrefixes());
+    util->setSpecialCalls(dataProxy->getSpecialCallsigns());
+    firstTime = _firstTime;
+    configFileName = _configFile;
+    version = _softwareVersion;
+    pageRequested = _page;
 
     slotReadConfigData();
     //qDebug() << Q_FUNC_INFO << ": 05.1" << QT_ENDL;
@@ -125,9 +138,7 @@ SetupDialog::SetupDialog(DataProxy_SQLite *dp, const QString &_configFile, const
     }
     //qDebug() << Q_FUNC_INFO << ": 5.3" << QT_ENDL;
     nolog = !(haveAtleastOneLog());
-    //hamlibPage->slotTestHamlib ();
-    connect(closeButton, SIGNAL(clicked()), this, SLOT(slotCancelButtonClicked()));
-    connect(okButton, SIGNAL(clicked()), this, SLOT(slotOkButtonClicked()));
+
     connectActions();
     //qDebug() << Q_FUNC_INFO << " - END" << QT_ENDL;
 }
@@ -148,11 +159,15 @@ SetupDialog::~SetupDialog()
     delete(satsPage);
     delete(hamlibPage);
     delete(logViewPage);
+    delete(util);
 }
 
 void SetupDialog::connectActions()
 {
-    emit debugLog (Q_FUNC_INFO, "Start", logSeverity);
+    //qDebug() << Q_FUNC_INFO;
+    logEvent(Q_FUNC_INFO, "Start", Debug);
+    connect(closeButton, SIGNAL(clicked()), this, SLOT(slotCancelButtonClicked()));
+    connect(okButton, SIGNAL(clicked()), this, SLOT(slotOkButtonClicked()));
     connect (logsPage, SIGNAL(newLogData(QStringList)), this, SLOT(slotAnalyzeNewLogData(QStringList)));
     connect(logsPage, SIGNAL(focusOK()), this, SLOT(slotFocusOK()) );
     connect (userDataPage, SIGNAL(mainCallsignSignal(QString)), this, SLOT(slotSetStationCallSign(QString)));
@@ -163,7 +178,7 @@ void SetupDialog::connectActions()
     //connect (clubLogPage, SIGNAL(enterKey()), this, SLOT(slotOkButtonClicked()));
     connect (eLogPage, SIGNAL(qrzcomAuto(bool)), this, SLOT(slotQRZCOMAuto(bool)));
 
-    emit debugLog (Q_FUNC_INFO, "END", logSeverity);
+    logEvent(Q_FUNC_INFO, "END", Debug);
 }
 
 void SetupDialog::slotQRZCOMAuto(const bool _b)
@@ -174,7 +189,7 @@ void SetupDialog::slotQRZCOMAuto(const bool _b)
 void SetupDialog::setData(const QString &_configFile, const QString &_softwareVersion, const int _page, const bool _firstTime)
 {
       //qDebug() << "SetupDialog::setData: " << "/" << _configFile << "/" << _softwareVersion << "/" << QString::number(_page) << QT_ENDL;
-    emit debugLog (Q_FUNC_INFO, "Start", logSeverity);
+    logEvent(Q_FUNC_INFO, "Start", Debug);
     nolog = !(haveAtleastOneLog());
     firstTime = _firstTime;
     if (firstTime)
@@ -192,44 +207,44 @@ void SetupDialog::setData(const QString &_configFile, const QString &_softwareVe
     slotReadConfigData ();
     setPage(_page);
     //removeBandModeDuplicates();
-    emit debugLog (Q_FUNC_INFO, "END", logSeverity);
+    logEvent(Q_FUNC_INFO, "END", Debug);
       //qDebug() << "SetupDialog::setData - END" << QT_ENDL;
 }
 
 void SetupDialog::setConfigFile(const QString &_configFile)
 {
        //qDebug() << "SetupDialog::setConfigFile" << QT_ENDL;
-    emit debugLog (Q_FUNC_INFO, "Start", logSeverity);
+    logEvent(Q_FUNC_INFO, "Start", Debug);
     configFileName = _configFile;
-    emit debugLog (Q_FUNC_INFO, "END", logSeverity);
+    logEvent(Q_FUNC_INFO, "END", Debug);
 }
 
 void SetupDialog::setSoftVersion(const QString &_softwareVersion)
 {
        //qDebug() << "SetupDialog::setSoftVersion" << QT_ENDL;
-    emit debugLog (Q_FUNC_INFO, "Start", logSeverity);
+    logEvent(Q_FUNC_INFO, "Start", Debug);
     version = _softwareVersion;
-    emit debugLog (Q_FUNC_INFO, "END", logSeverity);
+    logEvent(Q_FUNC_INFO, "END", Debug);
 }
 
 
 void SetupDialog::setPage(const int _page)
 {
        //qDebug() << "SetupDialog::setPage("<<QString::number(_page) << ")" << QT_ENDL;
-    emit debugLog (Q_FUNC_INFO, "Start", logSeverity);
+    logEvent(Q_FUNC_INFO, "Start", Debug);
     pageRequested = _page;
 
     if ((pageRequested==6) && (logsPageTabN>0))// The user is opening a new log
     {
         tabWidget->setCurrentIndex(pageRequested);
     }
-    emit debugLog (Q_FUNC_INFO, "END", logSeverity);
+    logEvent(Q_FUNC_INFO, "END", Debug);
 }
 
 void SetupDialog::slotCancelButtonClicked()
 {
       //qDebug() << "SetupDialog::slotCancelButtonClicked" << QT_ENDL;
-    emit debugLog (Q_FUNC_INFO, "Start", logSeverity);
+    logEvent(Q_FUNC_INFO, "Start", Debug);
     if (firstTime || nolog)
     {
         if (nolog)
@@ -243,13 +258,13 @@ void SetupDialog::slotCancelButtonClicked()
             int ret = msgBox.exec();
             if (ret == QMessageBox::No)
             {
-                emit debugLog (Q_FUNC_INFO, "END-1", logSeverity);
+                emit debugLog (Q_FUNC_INFO, "END-1", logLevel);
                 emit exitSignal(2);
                 return;
             }
             else
             {
-                emit debugLog (Q_FUNC_INFO, "END-2", logSeverity);
+                emit debugLog (Q_FUNC_INFO, "END-2", logLevel);
                 return;
             }
         }
@@ -257,13 +272,13 @@ void SetupDialog::slotCancelButtonClicked()
     hamlibPage->stopHamlib();
     QDialog::reject ();
     close();
-    emit debugLog (Q_FUNC_INFO, "END", logSeverity);
+    logEvent(Q_FUNC_INFO, "END", Debug);
 }
 
 void SetupDialog::createIcons()
 {
        //qDebug() << "SetupDialog::createIcons" << QT_ENDL;
-    emit debugLog (Q_FUNC_INFO, "Start", logSeverity);
+    logEvent(Q_FUNC_INFO, "Start", Debug);
     QListWidgetItem *configButton = new QListWidgetItem(contentsWidget);
     configButton->setIcon(QIcon(":/images/config.png"));
     configButton->setText(tr("User data"));
@@ -309,26 +324,26 @@ void SetupDialog::createIcons()
     connect(contentsWidget,
             SIGNAL(currentItemChanged(QListWidgetItem*,QListWidgetItem*)),
             this, SLOT(changePage(QListWidgetItem*,QListWidgetItem*)));
-    emit debugLog (Q_FUNC_INFO, "END", logSeverity);
+    logEvent(Q_FUNC_INFO, "END", Debug);
 }
 
 void SetupDialog::changePage(QListWidgetItem *current, QListWidgetItem *previous)
 {
        //qDebug() << "SetupDialog::changePage" << QT_ENDL;
-    emit debugLog (Q_FUNC_INFO, "Start", logSeverity);
+    logEvent(Q_FUNC_INFO, "Start", Debug);
     if (!current)
         current = previous;
 
     pagesWidget->setCurrentIndex(contentsWidget->row(current));
-    emit debugLog (Q_FUNC_INFO, "END", logSeverity);
+    logEvent(Q_FUNC_INFO, "END", Debug);
 }
 
 
 
 void SetupDialog::slotOkButtonClicked()
 {
-    //qDebug() << "SetupDialog::slotOkButtonClicked" << QT_ENDL;
-    emit debugLog (Q_FUNC_INFO, "Start", logSeverity);
+    //qDebug() << Q_FUNC_INFO ;
+    logEvent(Q_FUNC_INFO, "Start", Debug);
 
     if (!miscPage->areDBPathChangesApplied())
     {
@@ -337,7 +352,7 @@ void SetupDialog::slotOkButtonClicked()
         msgBox.setText(tr("DB has not been moved to new path."));
         msgBox.setInformativeText(tr("Go to the Misc tab and click on Move DB\n or the DB will not be moved to the new location."));
         msgBox.exec();
-        emit debugLog (Q_FUNC_INFO, "END-1", logSeverity);
+        emit debugLog (Q_FUNC_INFO, "END-1", logLevel);
         return;
     }
 
@@ -347,7 +362,7 @@ void SetupDialog::slotOkButtonClicked()
         msgBox.setText(tr("You need to enter at least a valid callsign."));
         msgBox.setInformativeText(tr("Go to the User tab and enter valid callsign."));
         msgBox.exec();
-        emit debugLog (Q_FUNC_INFO, "END-2", logSeverity);
+        emit debugLog (Q_FUNC_INFO, "END-2", logLevel);
         return;
     }
 
@@ -364,13 +379,13 @@ void SetupDialog::slotOkButtonClicked()
         logsPage->createNewLog();
         //emit newLogRequested(true); // Signal to be catched by logsPage true show new log
 
-        emit debugLog (Q_FUNC_INFO, "END-3", logSeverity);
+        emit debugLog (Q_FUNC_INFO, "END-3", logLevel);
         return;
     }
     //qDebug() << "SetupDialog::slotOkButtonClicked - 10" << QT_ENDL;
     QFile file (configFileName);
-    QString tmp;
-    tmp = "true";
+
+
     if (!file.open (QIODevice::WriteOnly))   /* Flawfinder: ignore */
     {
       QDialog::reject();
@@ -465,6 +480,7 @@ void SetupDialog::slotOkButtonClicked()
 
         //stream << "InMemory=" << miscPage->getInMemory() << ";" <<  QT_ENDL;
         stream << "RealTime=" << miscPage->getRealTime() << ";" <<  QT_ENDL;
+        stream << "ShowSeconds=" << util->boolToQString(miscPage->getShowSeconds())<< ";" <<  QT_ENDL;
         stream << "UTCTime=" << miscPage->getUTCTime() << ";" <<  QT_ENDL;
         stream << "AlwaysADIF=" << miscPage->getAlwaysADIF() << ";" <<  QT_ENDL;
         stream << "UseDefaultName=" << miscPage->getUseDefaultName() << ";" <<  QT_ENDL;
@@ -476,7 +492,7 @@ void SetupDialog::slotOkButtonClicked()
         stream << "CompleteWithPrevious=" << miscPage->getCompleteWithPrevious() << ";" <<  QT_ENDL;
         stream << "CheckNewVersions=" << miscPage->getCheckNewVersions() << ";" <<  QT_ENDL;
         stream << "ManageDXMarathon=" << miscPage->getDXMarathon() << ";" <<  QT_ENDL;
-        stream << "DebugLog=" << miscPage->getDebugLog() << ";" << QT_ENDL;
+        stream << "DebugLog=" << miscPage->getDebugLogLevel() << ";" << QT_ENDL;
         stream << "SendEQSLByDefault=" << miscPage->getSendEQSLByDefault() << ";" << QT_ENDL;
         stream << "DeleteAlwaysAdiFile=" << miscPage->getDeleteAlwaysAdiFile() << ";" << QT_ENDL;
         stream << "CheckValidCalls=" << util->boolToQString (miscPage->getCheckCalls())<< ";" << QT_ENDL;
@@ -496,10 +512,11 @@ void SetupDialog::slotOkButtonClicked()
         {
             stream << "ProvideInfo=True;"  <<  QT_ENDL;
         }
-
-        if ((!(dxClusterPage->getSelectedDxClusterServer()).isNull()) && (  (dxClusterPage->getSelectedDxClusterServer()).length() > 0   ))
+        QString tmp;
+        tmp = dxClusterPage->getSelectedDxClusterServer();
+        if (!(tmp.isNull()) && (  tmp.length() > 0   ))
         {
-            stream << "DXClusterServerToUse=" << dxClusterPage->getSelectedDxClusterServer() <<";" << QT_ENDL;
+            stream << "DXClusterServerToUse=" << tmp <<";" << QT_ENDL;
         }
 
         QStringList stringList;
@@ -639,7 +656,7 @@ void SetupDialog::slotOkButtonClicked()
         //qDebug() << "SetupDialog::slotOkButtonClicked - 60" << QT_ENDL;
 
         // LOTW
-        stream << "LoTWActive=" << eLogPage->getLoTWActive() << ";" <<  QT_ENDL;
+        stream << "LoTWActive=" << util->boolToQString(eLogPage->getLoTWActive()) << ";" <<  QT_ENDL;
         tmp = eLogPage->getTQSLPath();
         if (tmp.length()>0)
         {
@@ -688,7 +705,7 @@ void SetupDialog::slotOkButtonClicked()
     hamlibPage->stopHamlib();
     //qDebug() << "SetupDialog::slotOkButtonClicked - just before leaving" << QT_ENDL;
     QDialog::accept();
-    emit debugLog (Q_FUNC_INFO, "END", logSeverity);
+    logEvent(Q_FUNC_INFO, "END", Debug);
     //qDebug() << "SetupDialog::slotOkButtonClicked - END" << QT_ENDL;
     //close();
 }
@@ -696,7 +713,7 @@ void SetupDialog::slotOkButtonClicked()
 void SetupDialog::slotReadConfigData()
 {
     //qDebug() << "SetupDialog::slotReadConfigData" << QT_ENDL;
-    emit debugLog (Q_FUNC_INFO, "Start", logSeverity);
+    logEvent(Q_FUNC_INFO, "Start", Debug);
     if (firstTime)
     {
         //qDebug() << "SetupDialog::slotReadConfigData - First time" << QT_ENDL;
@@ -716,7 +733,7 @@ void SetupDialog::slotReadConfigData()
     {
         //qDebug() << "SetupDialog::slotReadConfigData() File not found" << configFileName << QT_ENDL;
         //firstTime = true;
-        emit debugLog (Q_FUNC_INFO, "END-1", logSeverity);
+        emit debugLog (Q_FUNC_INFO, "END-1", logLevel);
         return;
     }
     //qDebug() << "SetupDialog::slotReadConfigData - 2" << QT_ENDL;
@@ -751,13 +768,13 @@ void SetupDialog::slotReadConfigData()
     logViewFields.removeDuplicates();
     logViewPage->setActiveFields(logViewFields);
     //qDebug() << "SetupDialog::slotReadConfigData - END" << QT_ENDL;
-    emit debugLog (Q_FUNC_INFO, "END", logSeverity);
+    logEvent(Q_FUNC_INFO, "END", Debug);
 }
 
 bool SetupDialog::processConfigLine(const QString &_line)
 {
     //qDebug() << "SetupDialog::processConfigLine: " << _line << QT_ENDL;
-    emit debugLog (Q_FUNC_INFO, "Start", logSeverity);
+    logEvent(Q_FUNC_INFO, "Start", Debug);
 
     QString line = _line.simplified();
     //line.simplified();
@@ -767,20 +784,20 @@ bool SetupDialog::processConfigLine(const QString &_line)
 
     if (line.startsWith('#')){
            //qDebug() << "SetupDialog::processConfigLine: Comment Line!" << QT_ENDL;
-        emit debugLog (Q_FUNC_INFO, "END-1", logSeverity);
+        emit debugLog (Q_FUNC_INFO, "END-1", logLevel);
         return true;
     }
     if (!( (line.contains('=')) && (line.contains(';')))){
            //qDebug() << "SetupDialog::processConfigLine: Wrong Line!" << QT_ENDL;
-        emit debugLog (Q_FUNC_INFO, "END-2", logSeverity);
+        emit debugLog (Q_FUNC_INFO, "END-2", logLevel);
         return false;
     }
     QString value = values.at(1);
     tab = (values.at(0)).toUpper();
 
     int endValue = value.indexOf(';');
-    if (endValue>-1){
-
+    if (endValue>-1)
+    {
         value = value.left(value.length() - (value.length() - endValue));
     }
     value = checkAndFixASCIIinADIF(value); // Check whether the value is valid.
@@ -816,6 +833,8 @@ bool SetupDialog::processConfigLine(const QString &_line)
         logViewPage->setActiveFields(logViewFields);
     }else if (tab=="REALTIME"){
         miscPage->setRealTime(value);
+    }else if (tab=="SHOWSECONDS"){
+        miscPage->setShowSeconds (util->trueOrFalse (value));
     }else if (tab=="UTCTIME"){
         miscPage->setUTCTime(value);
     }else if (tab=="ALWAYSADIF"){
@@ -836,7 +855,7 @@ bool SetupDialog::processConfigLine(const QString &_line)
     }else if (tab=="MANAGEDXMARATHON"){
         miscPage->setDXMarathon(value.toUpper());
     }else if (tab=="DEBUGLOG"){
-        miscPage->setDebugLog(value);
+        miscPage->setDebugLogLevel(value);
     }
     else if (tab=="SHOWCALLSIGNINSEARCH"){
         miscPage->setShowStationCallSignInSearch(value.toUpper());
@@ -967,8 +986,8 @@ bool SetupDialog::processConfigLine(const QString &_line)
     {
         userDataPage->setAntenna3(value);
     }
-    else if (tab =="STATIONLOCATOR"){
-
+    else if (tab =="STATIONLOCATOR")
+    {
         if ( locator->isValidLocator(value) )
         {
             userDataPage->setStationLocator(value);
@@ -1101,7 +1120,7 @@ bool SetupDialog::processConfigLine(const QString &_line)
     }
     else if(tab =="QRZCOMACTIVE"){
         //eQSLPage->setActive(value);
-        eLogPage->setQRZCOMActive(value);
+        eLogPage->setQRZCOMActive(util->trueOrFalse(value));
     }
     else if(tab =="QRZCOMSUBSCRIBER"){
         eLogPage->setQRZCOMSubscriber(util->trueOrFalse (value));
@@ -1110,7 +1129,7 @@ bool SetupDialog::processConfigLine(const QString &_line)
         eLogPage->setQRZCOMUser(value);
     }
     else if(tab =="QRZCOMAUTO"){
-        eLogPage->setQRZCOMAutoCheck(value);
+        eLogPage->setQRZCOMAutoCheck(util->trueOrFalse(value));
     }
     else if(tab =="QRZCOMPASS"){
         eLogPage->setQRZCOMPassword(value);
@@ -1161,7 +1180,7 @@ bool SetupDialog::processConfigLine(const QString &_line)
     // Lines are: Option = value;
 
        //qDebug() << "SetupDialog::processConfigLine: END "  << QT_ENDL;
-    emit debugLog (Q_FUNC_INFO, "END", logSeverity);
+    logEvent(Q_FUNC_INFO, "END", Debug);
     return true;
 }
 
@@ -1170,7 +1189,7 @@ void SetupDialog::readActiveBands (const QString &actives)
     // bands used in the program
       //qDebug() << "SetupDialog::readActiveBands: " << actives << QT_ENDL;
 
-    emit debugLog (Q_FUNC_INFO, "Start", logSeverity);
+    logEvent(Q_FUNC_INFO, "Start", Debug);
     bool atLeastOne = false;
 
     QStringList values = actives.split(", ", QT_SKIP);
@@ -1199,13 +1218,13 @@ void SetupDialog::readActiveBands (const QString &actives)
     bands << _abands;
     bands.removeDuplicates();
     //qDebug() << Q_FUNC_INFO << " - END";
-    emit debugLog (Q_FUNC_INFO, "END", logSeverity);
+    logEvent(Q_FUNC_INFO, "END", Debug);
 }
 
 void SetupDialog::readActiveModes (const QString &actives)
 {
        //qDebug() << "SetupDialog::readActiveModes: " << actives << QT_ENDL;
-    emit debugLog (Q_FUNC_INFO, "Start", logSeverity);
+    logEvent(Q_FUNC_INFO, "Start", Debug);
 
     bool atLeastOne = false;
     QStringList _amodes;//, _backModes;
@@ -1231,35 +1250,35 @@ void SetupDialog::readActiveModes (const QString &actives)
     modes = dataProxy->getModesInLog(-1);
     modes << _amodes;
     modes.removeDuplicates();
-    emit debugLog (Q_FUNC_INFO, "END", logSeverity);
+    logEvent(Q_FUNC_INFO, "END", Debug);
        //qDebug() << "SetupDialog::readActiveModes: " << modes.join(" / ") << QT_ENDL;
 }
 
 bool SetupDialog::isValidBand (const QString &b)
 {
        //qDebug() << "SetupDialog::isValidBand: "<< b << QT_ENDL;
-    emit debugLog (Q_FUNC_INFO, "Start", logSeverity);
+    logEvent(Q_FUNC_INFO, "Start", Debug);
     QString stringQuery = QString("SELECT id FROM band WHERE name='%1'").arg(b);
     QSqlQuery query(stringQuery);
     query.next();
-    emit debugLog (Q_FUNC_INFO, "END", logSeverity);
+    logEvent(Q_FUNC_INFO, "END", Debug);
     return query.isValid();
 }
 bool SetupDialog::isValidMode (const QString &b)
 {
        //qDebug() << "SetupDialog::isValidMode: " << b << QT_ENDL;
-    emit debugLog (Q_FUNC_INFO, "Start", logSeverity);
+    logEvent(Q_FUNC_INFO, "Start", Debug);
     QString stringQuery = QString("SELECT id FROM mode WHERE name='%1'").arg(b);
     QSqlQuery query(stringQuery);
     query.next();
-    emit debugLog (Q_FUNC_INFO, "END", logSeverity);
+    logEvent(Q_FUNC_INFO, "END", Debug);
     return query.isValid();
 }
 
 void SetupDialog::setDefaults()
 {
        //qDebug() << "SetupDialog::setDefaults" << QT_ENDL;
-    emit debugLog (Q_FUNC_INFO, "Start", logSeverity);
+    logEvent(Q_FUNC_INFO, "Start", Debug);
     miscPage->setRealTime("TRUE");
     miscPage->setUTCTime("TRUE");
     miscPage->setImperial("FALSE"); //Metric system is the default
@@ -1269,7 +1288,7 @@ void SetupDialog::setDefaults()
     miscPage->setCheckNewVersions("TRUE");
     miscPage->setReportInfo("FALSE");
     miscPage->setDXMarathon("FALSE");
-    miscPage->setDebugLog("FALSE");
+    miscPage->setDebugLogLevel(util->getDebugLevels().at(0));
     //miscPage->setLogSort("FALSE");
     miscPage->setSetEQSLByDefault("TRUE");
     miscPage->setCheckCalls (true);
@@ -1307,14 +1326,14 @@ void SetupDialog::setDefaults()
         bands << "10M" << "12M" << "15M" << "17M" << "20M" << "40M" << "80M" << "160M";
         bands.removeDuplicates();
     }
-    emit debugLog (Q_FUNC_INFO, "END", logSeverity);
+    logEvent(Q_FUNC_INFO, "END", Debug);
 }
 
 QString SetupDialog::checkAndFixASCIIinADIF(const QString &_data)
 {
        //qDebug() << "SetupDialog::checkAndFixASCIIinADIF " << _data << QT_ENDL;
 //TODO: this function is also in the FileManager class. Maybe I should call that one and keep just one copy
-    emit debugLog (Q_FUNC_INFO, "Start", logSeverity);
+    logEvent(Q_FUNC_INFO, "Start", Debug);
     ushort unicodeVal;
     QString st = _data;
     QString newString;
@@ -1332,28 +1351,28 @@ QString SetupDialog::checkAndFixASCIIinADIF(const QString &_data)
 
     // Show into another lineEdit
 
-    emit debugLog (Q_FUNC_INFO, "END", logSeverity);
+    logEvent(Q_FUNC_INFO, "END", Debug);
     return newString;
 }
 
 bool SetupDialog::haveAtleastOneLog()
 {
-    emit debugLog (Q_FUNC_INFO, "Start", logSeverity);
-    emit debugLog (Q_FUNC_INFO, "END-1", logSeverity);
+    logEvent(Q_FUNC_INFO, "Start", Debug);
+    emit debugLog (Q_FUNC_INFO, "END-1", logLevel);
     return dataProxy->haveAtLeastOneLog();
-    //emit debugLog (Q_FUNC_INFO, "END", logSeverity);
+    //logEvent(Q_FUNC_INFO, "END", Debug);
 }
 
 void SetupDialog::setClubLogActive(const bool _b)
 {
-    emit debugLog (Q_FUNC_INFO, "Start", logSeverity);
+    logEvent(Q_FUNC_INFO, "Start", Debug);
     eLogPage->setClubLogActive(_b);
-    emit debugLog (Q_FUNC_INFO, "END", logSeverity);
+    logEvent(Q_FUNC_INFO, "END", Debug);
 }
 
 void SetupDialog::setQRZCOMAutoCheckActive(const bool _b)
 {
-     eLogPage->setQRZCOMAutoCheck(util->boolToQString(_b));
+     eLogPage->setQRZCOMAutoCheck(_b);
 }
 
 void SetupDialog::setEQSLActive(const bool _b)
@@ -1363,8 +1382,8 @@ void SetupDialog::setEQSLActive(const bool _b)
 
 void SetupDialog::checkIfNewBandOrMode()
 {
-      //qDebug() << "SetupDialog::checkIfNewBandOrMode: logSeverity: " << QString::number(logSeverity) << QT_ENDL;
-    emit debugLog (Q_FUNC_INFO, "Start", logSeverity);
+      //qDebug() << "SetupDialog::checkIfNewBandOrMode: logLevel: " << QString::number(logLevel) << QT_ENDL;
+    logEvent(Q_FUNC_INFO, "Start", Debug);
     QStringList _items;
 
     _items.clear();
@@ -1383,7 +1402,7 @@ void SetupDialog::checkIfNewBandOrMode()
     _items << (bandModePage->getModes()).split(", ", QT_SKIP);
     _items.removeDuplicates();
     bandModePage->setActiveModes(_items);
-    emit debugLog (Q_FUNC_INFO, "END", logSeverity);
+    logEvent(Q_FUNC_INFO, "END", Debug);
        //qDebug() << "SetupDialog::checkIfNewBandOrMode END" << QT_ENDL;
 }
 
@@ -1393,47 +1412,47 @@ void SetupDialog::slotAnalyzeNewLogData(const QStringList _qs)
       //qDebug() << "SetupDialog::slotAnalyzeNewLogData (length=" << QString::number(_qs.length()) << ")" << QT_ENDL;
        //qDebug() << "SetupDialog::slotAnalyzeNewLogData" << QT_ENDL;
  // We receive the station callsign and operators from the logs tab
-    emit debugLog (Q_FUNC_INFO, "Start", logSeverity);
+    logEvent(Q_FUNC_INFO, "Start", Debug);
     if (_qs.length()!=2)
     {
-        emit debugLog (Q_FUNC_INFO, "END-1", logSeverity);
+        emit debugLog (Q_FUNC_INFO, "END-1", logLevel);
         return;
     }
     userDataPage->setMainCallsign(_qs.at(0));
     userDataPage->setOperators(_qs.at(1));
-    emit debugLog (Q_FUNC_INFO, "END", logSeverity);
+    logEvent(Q_FUNC_INFO, "END", Debug);
 }
 
 void SetupDialog::slotSetStationCallSign(const QString &_p)
 {
        //qDebug() << "SetupDialog::slotSetStationCallSign: " << _p << QT_ENDL;
-    emit debugLog (Q_FUNC_INFO, "Start", logSeverity);
+    logEvent(Q_FUNC_INFO, "Start", Debug);
     logsPage->setDefaultStationCallsign(_p);
-    emit debugLog (Q_FUNC_INFO, "END", logSeverity);
+    logEvent(Q_FUNC_INFO, "END", Debug);
 }
 
 void SetupDialog::slotSetOperators(const QString &_p)
 {
        //qDebug() << "SetupDialog::slotSetOperators: " << _p << QT_ENDL;
-    emit debugLog (Q_FUNC_INFO, "Start", logSeverity);
+    logEvent(Q_FUNC_INFO, "Start", Debug);
     logsPage->setDefaultOperators(_p);
-    emit debugLog (Q_FUNC_INFO, "END", logSeverity);
+    logEvent(Q_FUNC_INFO, "END", Debug);
 }
 
-void SetupDialog::setSeverity(const DebugLogLevel _sev)
+void SetupDialog::setLogLevel(const DebugLogLevel _sev)
 {
-    logSeverity = _sev;
+    logLevel = _sev;
+    miscPage->setDebugLogLevel(util->debugLevelToString(_sev));
 }
 
 void SetupDialog::slotQueryErrorManagement(QString functionFailed, QString errorCodeS, QString nativeError, QString failedQuery)
-{   emit debugLog (Q_FUNC_INFO, "Start", logSeverity);
+{   logEvent(Q_FUNC_INFO, "Start", Debug);
     emit queryError(functionFailed, errorCodeS, nativeError, failedQuery);
-    emit debugLog (Q_FUNC_INFO, "END", logSeverity);
+    logEvent(Q_FUNC_INFO, "END", Debug);
 }
 
 void SetupDialog::slotFocusOK()
 {
-      //qDebug() << "SetupDialog::slotFocusOK" << QT_ENDL;
     okButton->setFocus(Qt::OtherFocusReason);
 }
 
@@ -1444,3 +1463,9 @@ void SetupDialog::showEvent(QShowEvent *event)
     QWidget::showEvent(event);
     userDataPage->setStationFocus();
 }
+
+void SetupDialog::logEvent(const QString &_func, const QString &_msg,  DebugLogLevel _level)
+{
+    if (logLevel<=_level)
+        emit debugLog (_func, _msg, _level);
+}
