@@ -9,7 +9,8 @@ HamLibSerialConfigWidget::HamLibSerialConfigWidget(QWidget *parent) : QWidget(pa
     flowControlComboBox = new QComboBox();
     parityComboBox = new QComboBox();
     stopBitsComboBox = new QComboBox();
-    scanSerialPortButton = new QPushButton;
+
+    scanSerialPortButton = new QPushButton();
     //qDebug() << Q_FUNC_INFO << " - END";
 }
 
@@ -348,7 +349,7 @@ QString HamLibSerialConfigWidget::getSerialPort()
 
 int HamLibSerialConfigWidget::getSerialBauds()
 {
-    return (serialBaudsComboBox->currentText ()).toInt ();
+    return (serialBaudsComboBox->currentText ()).toInt();
 }
 
 
