@@ -2,7 +2,6 @@
 #define HAMLIBSERIALCONFIGWIDGET_H
 
 #include <QtWidgets>
-
 #include <QSerialPortInfo>
 #include "../klogdefinitions.h"
 
@@ -20,7 +19,7 @@ public:
     void setParity(const QString &_st);
     QString getParity();
     void setStopBits(const QString &_st);
-    int getStopBits();
+    QString getStopBits();
     bool setSerialBauds(const int _speed );
     bool setSerialPort(const QString &_port);
 
@@ -37,8 +36,8 @@ private:
 
     QPushButton *scanSerialPortButton;
     QComboBox *serialBaudsComboBox, *serialPortComboBox, *dataBitsComboBox, *flowControlComboBox, *parityComboBox, *stopBitsComboBox;
-    QLineEdit *dataFromRigLineEdit;
-    QLineEdit *serialPort;
+    //QLineEdit *dataFromRigLineEdit;
+    //QLineEdit *serialPort;
     QStringList serialPorts;
 };
 
