@@ -26,7 +26,7 @@
 
 //#include <QDebug>
 
-#include "setuppages/setuppagelogs.h"
+#include "setuppagelogs.h"
 
 SetupPageLogs::SetupPageLogs(DataProxy_SQLite *dp, QWidget *parent) : QWidget(parent){
     //qDebug() << "SetupPageLogs::SetupPageLogs" << QT_ENDL;
@@ -122,10 +122,8 @@ void SetupPageLogs::slotEditButtonClicked()
        //qDebug() << "SetupPageLogs::slotEditButtonClicked" << QT_ENDL;
     //QSqlQuery query;
     //int nameCol = -1;
-
     //selectedLog = getSelectedLog();
-
-    QString getStationCallSignFromLog(const int _log);
+    //QString call = getStationCallSignFromLog(const int _log);
 
     newLog->setEditing(true);
       //qDebug() << "SetupPageLogs::slotEditButtonClicked" << QT_ENDL;
@@ -210,8 +208,7 @@ void SetupPageLogs::slotRemoveButtonClicked()
             logsModel->select();
             updateSelectedLogs();
             stringQuery = QString("DELETE FROM log WHERE lognumber='%1'").arg(selectedLog);
-            query.exec(stringQuery);
-            sqlOk = query.exec();
+            sqlOk = query.exec(stringQuery);
                //qDebug() << "SetupPageLogs::slotRemoveButtonClicked: LastQuery: " << query.lastQuery()  << QT_ENDL;
             if (sqlOk)
             {
