@@ -28,12 +28,11 @@
 //
 // This class implements the Dialog to add a new log
 //
-#include "dataproxy_sqlite.h"
-#include "utilities.h"
-
 #include <QDialog>
 #include <QtWidgets>
 #include <QSqlQuery>
+#include "../dataproxy_sqlite.h"
+#include "../utilities.h"
 
 //TODO: Read the data when the user clicks the OK button
 //TODO: Fill the data from the list of logs when the user wants to edit a log
@@ -45,7 +44,7 @@ class SetupPageLogsNew : public QDialog
 public:
     //SetupPageLogsNew(QWidget *parent = 0);
     SetupPageLogsNew(DataProxy_SQLite *dp, QWidget *parent = nullptr);
-
+    ~SetupPageLogsNew();
     void setEditing(const bool b);
     void setStationCallSign(const QString &_st);
     void setOperators(const QString &_st);
