@@ -26,17 +26,18 @@
 
 //#include <QDebug>
 
-#include "setuppages/setuppagemisc.h"
+#include "setuppagemisc.h"
 //TODO: The defaultFileName QString can be removed and used the content of defaultFileNameLineEdit
 //      instead. It is easy to change but the code would not be so clear... Think about this. :-)
 
 SetupPageMisc::SetupPageMisc(QWidget *parent) : QWidget(parent){
        //qDebug() << "SetupPageMisc::SetupPageMisc" << QT_ENDL;
 
-    util = new Utilities;
+    util = new Utilities(Q_FUNC_INFO);
     checkCallsCheckBox = new QCheckBox(tr("Check non-valid calls"), this);
     imperialCheckBox = new QCheckBox(tr("&Imperial system"), this);
     realTimeCheckbox = new QCheckBox(tr("&Log in real time"), this);
+    showSecondsCheckBox = new QCheckBox(tr("Show seconds"), this);
     UTCCheckbox = new QCheckBox(tr("&Time in UTC"), this);
     alwaysADIFCheckBox = new QCheckBox(tr("&Save ADIF on exit"), this);
     useDefaultName = new QCheckBox(tr("Use this &default filename"), this);
@@ -47,12 +48,12 @@ SetupPageMisc::SetupPageMisc(QWidget *parent) : QWidget(parent){
     checkNewVersionCheckBox = new QCheckBox(tr("&Check for new versions automatically"), this);
     provideCallCheckBox = new QCheckBox(tr("&Provide Info for statistics"), this);
     useDxMarathonCheckBox = new QCheckBox(tr("Manage DX-Marathon"), this);
-    debugLogCheckBox = new QCheckBox(tr("Activate the application debug log"));
+
     //logSortCheckBox = new QCheckBox(tr("Sort log based in date && time"));
     sendEQSLByDefaultSearchCheckBox = new QCheckBox(tr("Mark sent eQSL && LoTW in new QSO as queued"));
     deleteAlwaysAdiFileCheckBox = new QCheckBox(tr("&Delete always temp ADIF file after uploading QSOs"));
 
-
+    debugLogLevelCombo = new QComboBox;
     dupeTimeLineEdit = new QLineEdit;
     defaultFileNameLineEdit = new QLineEdit;
     dbPathLineEdit = new QLineEdit;
@@ -102,6 +103,10 @@ void SetupPageMisc::createUI()
     dbDirNew = klogDir;     // The new path where the DB is to be moved
     dbDirCurrent = dbDirNew;       // The path where the DB is hosted
 
+    showSecondsCheckBox->setToolTip (tr("Show seconds in the QSO editor"));
+    showSecondsCheckBox->setChecked (true);
+    showSecondsCheckBox->setEnabled (true);
+
     defaultFileNameLineEdit->setReadOnly(false);
     defaultFileNameLineEdit->setText(defaultFileName);
     defaultFileNameLineEdit->setEnabled(false);
@@ -115,7 +120,7 @@ void SetupPageMisc::createUI()
     showStationCallWhenSearchCheckBox->setChecked(true);
     //keepMyDataCheckBox->setChecked(true);
     completeWithPreviousCheckBox->setChecked(false);
-    debugLogCheckBox->setChecked(false);
+    debugLogLevelCombo->setCurrentIndex (0);
     UTCCheckbox->setChecked(true);
     realTimeCheckbox->setChecked(true);
     //logSortCheckBox->setChecked(false);
@@ -142,50 +147,68 @@ void SetupPageMisc::createUI()
     fileNameButton->setToolTip(tr("Click to change the default ADIF file."));
     dbPushButton->setToolTip(tr("Click to change the path of the database."));
     moveDBPushButton->setToolTip(tr("Click to move the DB to the new directory."));
-    debugLogCheckBox->setToolTip(tr("Activates the application debug log. This may be useful if something is not working as expected. A debug file will be created in the KLog directory."));
+    debugLogLevelCombo->setToolTip(tr("Select the application debug log level. This may be useful if something is not working as expected. A debug file will be created in the KLog directory and/or shown with Help->Debug menu."));
     //logSortCheckBox->setToolTip(tr("Click to enable that log will be sorted based on date and time when clicking on the date column. It may be a little bit slower."));
     sendEQSLByDefaultSearchCheckBox->setToolTip(tr("Click to mark as Queued (to be sent) all the eQSL (LoTW and eQSL) in all the new QSO by default."));
     deleteAlwaysAdiFileCheckBox->setToolTip(tr("Delete Always the adif file created after uploading QSOs"));
 
+    fillDebugComboBox();
+
     QHBoxLayout *fileLayout = new QHBoxLayout;
     fileLayout->addWidget(useDefaultName);
     fileLayout->addWidget(defaultFileNameLineEdit);
     fileLayout->addWidget(fileNameButton);
 
     QHBoxLayout *dbLayout = new QHBoxLayout;
-
     dbLayout->addWidget(dbPathLineEdit);
     dbLayout->addWidget(dbPushButton);
     dbLayout->addWidget(moveDBPushButton);
 
+    QLabel *logLevelLabel = new QLabel;
+    logLevelLabel->setText(tr("Log level"));
+    QHBoxLayout *logLevelLayout = new QHBoxLayout;
+    logLevelLayout->addWidget(logLevelLabel);
+    logLevelLayout->addWidget(debugLogLevelCombo);
+
     QLabel *timeRangeLabel = new QLabel;
     timeRangeLabel->setText(tr("Dupe time range:"));
+
     QHBoxLayout *timeRangeLayout = new QHBoxLayout;
     timeRangeLayout->addWidget(timeRangeLabel);
     timeRangeLayout->addWidget(dupeTimeLineEdit);
 
-    QGridLayout *mainLayou1 = new QGridLayout;
-    mainLayou1->addLayout(fileLayout, 0, 0, 1, -1);
-    mainLayou1->addLayout(dbLayout, 1, 0, 1, -1);
-    mainLayou1->addWidget(alwaysADIFCheckBox, 2, 0, 1, 1);
-    mainLayou1->addWidget(debugLogCheckBox, 2, 1, 1, 1);
-    mainLayou1->addWidget(UTCCheckbox, 3, 0, 1, 1);
-    mainLayou1->addWidget(realTimeCheckbox, 3, 1, 1, 1);
-    mainLayou1->addWidget(imperialCheckBox, 4, 0, 1, 1);
-    mainLayou1->addWidget(useDxMarathonCheckBox, 4, 1, 1, 1);
-    mainLayou1->addLayout(timeRangeLayout, 5, 0, 1, 1);
-    mainLayou1->addWidget(completeWithPreviousCheckBox, 5, 1, 1, 1);
-    mainLayou1->addWidget(sendQSLWhenRecCheckBox,6, 0, 1, 1);
-    mainLayou1->addWidget(sendEQSLByDefaultSearchCheckBox, 6, 1, 1, 1);
-    mainLayou1->addWidget(checkNewVersionCheckBox, 7, 0, 1, 1);
-    mainLayou1->addWidget(provideCallCheckBox, 7, 1, 1, 1);
-    //mainLayou1->addWidget(logSortCheckBox, 8, 0, 1, 1);
-    mainLayou1->addWidget(showStationCallWhenSearchCheckBox, 8, 0, 1, 1);
-    mainLayou1->addWidget(deleteAlwaysAdiFileCheckBox, 8, 1, 1, 1);
-    mainLayou1->addWidget (checkCallsCheckBox, 9, 0, 1, 1);
+    QHBoxLayout *timeLayout = new QHBoxLayout;
+    timeLayout->addWidget (realTimeCheckbox);
+    timeLayout->addWidget (showSecondsCheckBox);
 
-    setLayout(mainLayou1);
+    QGridLayout *mainLayout = new QGridLayout;
+    mainLayout->addLayout(fileLayout, 0, 0, 1, -1);
+    mainLayout->addLayout(dbLayout, 1, 0, 1, -1);
+    mainLayout->addWidget(alwaysADIFCheckBox, 2, 0, 1, 1);
+    mainLayout->addLayout(logLevelLayout, 2, 1, 1, 1);
+    mainLayout->addWidget(UTCCheckbox, 3, 0, 1, 1);
+    //mainLayout->addWidget(realTimeCheckbox, 3, 1, 1, 1);
+    mainLayout->addLayout(timeLayout, 3, 1, 1, 1);
+    mainLayout->addWidget(imperialCheckBox, 4, 0, 1, 1);
+    mainLayout->addWidget(useDxMarathonCheckBox, 4, 1, 1, 1);
+    mainLayout->addLayout(timeRangeLayout, 5, 0, 1, 1);
+    mainLayout->addWidget(completeWithPreviousCheckBox, 5, 1, 1, 1);
+    mainLayout->addWidget(sendQSLWhenRecCheckBox,6, 0, 1, 1);
+    mainLayout->addWidget(sendEQSLByDefaultSearchCheckBox, 6, 1, 1, 1);
+    mainLayout->addWidget(checkNewVersionCheckBox, 7, 0, 1, 1);
+    mainLayout->addWidget(provideCallCheckBox, 7, 1, 1, 1);
+    //mainLayout->addWidget(logSortCheckBox, 8, 0, 1, 1);
+    mainLayout->addWidget(showStationCallWhenSearchCheckBox, 8, 0, 1, 1);
+    mainLayout->addWidget(deleteAlwaysAdiFileCheckBox, 8, 1, 1, 1);
+    mainLayout->addWidget (checkCallsCheckBox, 9, 0, 1, 1);
 
+    setLayout(mainLayout);
+}
+
+void SetupPageMisc::fillDebugComboBox()
+{
+    debugLogLevelCombo->addItems(util->getDebugLevels());
+    debugLogLevelCombo->setCurrentIndex(0);
 }
 
 void SetupPageMisc::createActions(){
@@ -199,7 +222,6 @@ void SetupPageMisc::createActions(){
     connect(dbPathLineEdit, SIGNAL(textChanged(QString)), this, SLOT(slotDBLineEditChanged() ) );
     connect(moveDBPushButton, SIGNAL(clicked() ), this, SLOT(slotMoveDBButtonClicked() ) );
     //connect(UDPServerCheckBox, SIGNAL(clicked () ), this, SLOT(slotUDPServerCheckBoxClicked() ) );
-
 }
 
 void SetupPageMisc::setDeleteAlwaysAdiFile(const bool &_t){
@@ -233,6 +255,16 @@ void SetupPageMisc::setRealTime(const QString &_t)
     realTimeCheckbox->setChecked(util->trueOrFalse(_t));
 }
 
+bool SetupPageMisc::getShowSeconds()
+{
+    return showSecondsCheckBox->isChecked ();
+}
+
+void SetupPageMisc::setShowSeconds(const bool &_t)
+{
+    showSecondsCheckBox->setChecked (_t);
+}
+
 QString SetupPageMisc::getUTCTime(){
 
     return util->boolToQString(UTCCheckbox->isChecked());
@@ -417,18 +449,19 @@ void SetupPageMisc::setDXMarathon(const QString &_t){
     useDxMarathonCheckBox->setChecked(util->trueOrFalse(_t));
 }
 
-QString SetupPageMisc::getDebugLog()
+QString SetupPageMisc::getDebugLogLevel()
 {
-    return util->boolToQString(debugLogCheckBox->isChecked());
+    return debugLogLevelCombo->currentText ();
 }
 
-void SetupPageMisc::setDebugLog(const QString &_t)
+void SetupPageMisc::setDebugLogLevel(const QString &_t)
 {
-    debugLogCheckBox->setChecked(util->trueOrFalse(_t));
+    if (util->isValidLogLevel(_t))
+        debugLogLevelCombo->setCurrentIndex(debugLogLevelCombo->findText(_t, Qt::MatchCaseSensitive));
+    else
+        debugLogLevelCombo->setCurrentIndex(0);
 }
 
-
-
 void SetupPageMisc::slotDBButtonClicked()
 {
 //    QString dbDirBack = dbDir;
@@ -592,3 +625,4 @@ void SetupPageMisc::setCheckCalls(const bool &_t)
 {
     checkCallsCheckBox->setChecked (_t);
 }
+
