@@ -28,7 +28,7 @@
 
 //#include <QtWidgets>
 #include <QtWidgets>
-#include "utilities.h"
+#include "../utilities.h"
 
 class SetupPageMisc : public QWidget {
     Q_OBJECT
@@ -39,6 +39,8 @@ public:
 
     QString getRealTime();
     void setRealTime(const QString &_t);
+    bool getShowSeconds();
+    void setShowSeconds(const bool &_t);
     QString getUTCTime();
     void setUTCTime(const QString &_t);
     QString getAlwaysADIF();
@@ -67,8 +69,8 @@ public:
     void setReportInfo(const QString &_t);
     QString getDXMarathon();
     void setDXMarathon(const QString &_t);
-    QString getDebugLog();
-    void setDebugLog(const QString &_t);
+    QString getDebugLogLevel();
+    void setDebugLogLevel(const QString &_t);
     //QString getLogSort();
     //void setLogSort(const QString &_t);
     QString getSendEQSLByDefault();
@@ -97,12 +99,13 @@ private slots:
 private:
     void createActions();
     void createUI();
+    void fillDebugComboBox();
 
     Utilities *util;
 
-    QCheckBox *realTimeCheckbox, *UTCCheckbox, *alwaysADIFCheckBox, *useDefaultName, *completeWithPreviousCheckBox;
+    QCheckBox *realTimeCheckbox, *showSecondsCheckBox, *UTCCheckbox, *alwaysADIFCheckBox, *useDefaultName, *completeWithPreviousCheckBox;
     QCheckBox *imperialCheckBox, *sendQSLWhenRecCheckBox, *showStationCallWhenSearchCheckBox;
-    QCheckBox *checkNewVersionCheckBox, *provideCallCheckBox, *useDxMarathonCheckBox, *debugLogCheckBox, *checkCallsCheckBox;
+    QCheckBox *checkNewVersionCheckBox, *provideCallCheckBox, *useDxMarathonCheckBox, *checkCallsCheckBox;
     //QCheckBox *logSortCheckBox;
     QCheckBox *sendEQSLByDefaultSearchCheckBox, *deleteAlwaysAdiFileCheckBox;
     QString defaultFileName;
@@ -115,6 +118,7 @@ private:
 
     bool dbPathApplied;
 
+    QComboBox *debugLogLevelCombo;
     //QWidget *bandsWidget;
 
 };
