@@ -27,14 +27,14 @@
 // This class implements the Dialog to add a new log
 //
 
-#include "setuppages/setuppagesatsnew.h"
+#include "setuppagesatsnew.h"
 
 
 SetupPageSatsNew::SetupPageSatsNew(DataProxy_SQLite *dp, QWidget *parent)
 {
        //qDebug() << "SetupPageSatsNew::SetupPageSatsNew"   << QT_ENDL;
     dataProxy = dp;
-    util = new Utilities;
+    util = new Utilities(Q_FUNC_INFO);
     editing = false;
     //checking = false;
 
@@ -212,11 +212,7 @@ void SetupPageSatsNew::slotUpLinkTextChanged()
         }
         else
         { //It is just one freq
-            if (isItAFreq(aux))
-            {
-
-            }
-            else
+            if (!isItAFreq(aux))
             {
                 hasUplink = false;
             }
@@ -260,10 +256,6 @@ void SetupPageSatsNew::slotDownLinkTextChanged()
         else
         { //It is just one freq
             if (isItAFreq(aux))
-            {
-
-            }
-            else
             {
                 hasDownlink = false;
             }
