@@ -26,14 +26,14 @@
 
 //#include <QDebug>
 
-#include "setuppages/setuppagesubdivisions.h"
+#include "setuppagesubdivisions.h"
 
 
 SetupPageSubdivisions::SetupPageSubdivisions(DataProxy_SQLite *dp, QWidget *parent) : QWidget(parent){
        //qDebug() << "SetupPageSubdivisions::SetupPageSubdivisions" << QT_ENDL;
     dataProxy = dp;
     fileAwardManager = new FileAwardManager(dataProxy, Q_FUNC_INFO);
-    //util = new Utilities();
+    //util = new Utilities(Q_FUNC_INFO);
     selectedLog = -1;
     currentLogs = new QComboBox();
     logsAvailable.clear();
@@ -84,6 +84,7 @@ SetupPageSubdivisions::SetupPageSubdivisions(DataProxy_SQLite *dp, QWidget *pare
 
 SetupPageSubdivisions::~SetupPageSubdivisions(){
        //qDebug() << "SetupPageSubdivisions::~SetupPageSubdivisions" << QT_ENDL;
+    delete(fileAwardManager);
 }
 
 /*
@@ -103,7 +104,7 @@ void SetupPageSubdivisions::slotEditButtonClicked()
     newLog->setOperators(dataProxy->getOperatorsFromLog(selectedLog));
     newLog->setComment(dataProxy->getCommentsFromLog(selectedLog));
     newLog->setDateString(dataProxy->getLogDateFromLog(selectedLog));
-    //newLog->setTypeN(dataProxy->getLogTypeNFromLog(selectedLog).toInt());    
+    //newLog->setTypeN(dataProxy->getLogTypeNFromLog(selectedLog).toInt());
     int result = newLog->exec();
     if (result == QDialog::Accepted)
     {
