@@ -24,12 +24,12 @@
  *                                                                           *
  *****************************************************************************/
 
-#include "setuppages/setuppageuserdata.h"
+#include "setuppageuserdata.h"
 
 SetupPageUserDataPage::SetupPageUserDataPage(DataProxy_SQLite *dp, QWidget *parent) : QWidget(parent){
       //qDebug() << "SetupPageUserDataPage::SetupPageUserDataPage" << QT_ENDL;
    locator = new Locator();
-   util = new Utilities;
+   util = new Utilities(Q_FUNC_INFO);
    dataProxy = dp;
    world = new World(dataProxy, Q_FUNC_INFO);
    mainCallOK = false;
@@ -123,7 +123,6 @@ SetupPageUserDataPage::SetupPageUserDataPage(DataProxy_SQLite *dp, QWidget *pare
 
    personalTab->setLayout(personalLayout);
 
-
    // Station Tab
    rig1LineEdit = new QLineEdit;
    rig2LineEdit = new QLineEdit;
@@ -246,6 +245,8 @@ SetupPageUserDataPage::SetupPageUserDataPage(DataProxy_SQLite *dp, QWidget *pare
     setLayout(mainLayout);
     maincallsignLineEdit->setFocus();
 
+    util->setLongPrefixes(dataProxy->getLongPrefixes());
+    util->setSpecialCalls(dataProxy->getSpecialCallsigns());
        //qDebug() << "SetupPageUserDataPage::SetupPageUserDataPage - END" << QT_ENDL;
 }
 
@@ -253,12 +254,18 @@ SetupPageUserDataPage::SetupPageUserDataPage(DataProxy_SQLite *dp, QWidget *pare
 SetupPageUserDataPage::~SetupPageUserDataPage()
 {
        //qDebug() << "SetupPageUserDataPage::~SetupPageUserDataPage" << QT_ENDL;
+    delete(locator);
+    delete(util);
+    delete(world);
+    delete(defaultPalette);
+    delete(wrongPalette);
+    delete(dataProxy);
 }
 
 QString SetupPageUserDataPage::getMainCallsign()
 {
-    mainCallOK = world->checkQRZValidFormat(maincallsignLineEdit->text());
-    if (mainCallOK)
+    //mainCallOK = world->checkQRZValidFormat(maincallsignLineEdit->text());
+    if (util->isValidCall(maincallsignLineEdit->text()))
     {
         return maincallsignLineEdit->text();
     }
@@ -629,33 +636,16 @@ void SetupPageUserDataPage::slotOperatorsChanged()
     for (int ii = 0; ii < operators.size(); ++ii)
     {
            //qDebug() << "SetupPageUserDataPage::slotOperatorsChanged-03 - " << QString::number(ii) << QT_ENDL;
-
-        operatorsOK = world->checkQRZValidFormat(operators.at(ii));
-
-        //ent = world->getQRZARRLId(operators.at(ii));
-
-        if (operatorsOK)
-        {
-               //qDebug() << "SetupPageUserDataPage::slotOperatorsChanged: NO  VALID CALL: " <<  operators.at(ii) << QT_ENDL;
-        }
-        else
-        {
-               //qDebug() << "SetupPageUserDataPage::slotOperatorsChanged: VALID CALL: " <<  operators.at(ii) << QT_ENDL;
-        }
+        operatorsOK = util->isValidCall(operators.at(ii));
+        //operatorsOK = world->checkQRZValidFormat(operators.at(ii));
     }
-    //          cout << fonts.at(i).toLocal8Bit().constData() << QT_ENDL;
-
        //qDebug() << "SetupPageUserDataPage::slotOperatorsChanged-04" << QT_ENDL;
 
     if (operatorsOK)
     {
-           //qDebug() << "SetupPageUserDataPage::slotOperatorsChanged: VALID FORMAT" << QT_ENDL;
-        //QColor defaultColor = (operatorsLineEdit->palette()).color(QPalette::WindowText);
-
+        //qDebug() << "SetupPageUserDataPage::slotOperatorsChanged: VALID FORMAT" << QT_ENDL;
         operatorsLineEdit->setPalette(*defaultPalette);
-
         emit operatorsSignal(operatorsLineEdit->text());
-
     }
     else
     {
@@ -663,15 +653,6 @@ void SetupPageUserDataPage::slotOperatorsChanged()
            //qDebug() << "SetupPageUserDataPage::slotOperatorsChanged: NOT VALID FORMAT" << QT_ENDL;
     }
        //qDebug() << "SetupPageUserDataPage::slotOperatorsChanged-05" << QT_ENDL;
-
- /*
-    cqzLineEdit->setText(QString::number(world->getQRZCqz(maincallsignLineEdit->text())));
-    ituzLineEdit->setText(QString::number(world->getQRZItuz(maincallsignLineEdit->text())));
-    myLocatorLineEdit->setText(world->getQRZLocator(maincallsignLineEdit->text()));
-
-
-  */
-    //operatorsLineEdit->setText(_a);
     operatorsLineEdit->setCursorPosition(i);
        //qDebug() << "SetupPageUserDataPage::slotOperatorsChanged-END" << QT_ENDL;
 }
@@ -705,10 +686,10 @@ bool  SetupPageUserDataPage::checkOperatorsLineQString(const QString &_auxLine)
     QStringList _aux = _auxLine.split(',');
     for (int ii = 0; ii < _aux.size(); ++ii)
     {
-        operatorsOK = world->checkQRZValidFormat(_aux.at(ii));
+        operatorsOK = util->isValidCall(_aux.at(ii));
+        //operatorsOK = world->checkQRZValidFormat(_aux.at(ii));
         if (!operatorsOK)
             return operatorsOK;
-
     }
     return true;
 }
