@@ -25,12 +25,11 @@
  *****************************************************************************/
 
 #include "softwareupdate.h"
-//#include <QDebug>
 
 SoftwareUpdate::SoftwareUpdate(const QString &_klogVersion) : QObject(nullptr)
 {
       //qDebug() << "SoftwareUpdate::SoftwareUpdate(): " << _klogVersion << QT_ENDL;
-    util = new Utilities;
+    util = new Utilities(Q_FUNC_INFO);
     updateDialog = new SoftwareUpdateDialog();
     latestVersion = "0.0";
     repositoryFound = false;
