@@ -43,7 +43,7 @@ class TipsDialog : public QDialog
 public:
     explicit TipsDialog(QWidget *parent = nullptr);
     ~TipsDialog();
-    void setSeverity(const DebugLogLevel _sev);
+    void setLogLevel(const DebugLogLevel _sev);
 
 signals:
     void debugLog (QString _func, QString _msg, DebugLogLevel _level);
@@ -65,11 +65,12 @@ private slots:
 
 private:
     void setTip(const int _t);
+    void logEvent(const QString &_func, const QString &_msg, DebugLogLevel _level);
 
     QLabel *tipTextQLabel;
     //QTextEdit *tipTextEdit;
     QWidget *tip;
-    DebugLogLevel logSeverity;
+    DebugLogLevel logLevel;
     int tipId, tipMax;
     QString description;
 
