@@ -50,13 +50,17 @@ UDPServer::UDPServer(QObject *parent) :
             //qDebug() << "UDPServer::UDPServer - Multicast group joined NOK"  << QT_ENDL;
        }
        */
-        util = new Utilities;
+        util = new Utilities(Q_FUNC_INFO);
         logging = false;
         realtime = false;
-
         connect(socketServer,SIGNAL(readyRead()),this,SLOT(slotReadPendingDatagrams()));
 }
 
+UDPServer::~UDPServer()
+{
+    delete(util);
+}
+
 void UDPServer::slotReadPendingDatagrams()
 {
        //qDebug() << "UDPServer::slotReadPendingDatagrams"  << QT_ENDL;
@@ -70,7 +74,6 @@ void UDPServer::slotReadPendingDatagrams()
         parse (datagram);
         //qDebug() << "UDPServer::slotReadPendingDatagrams: = " << datagram << QT_ENDL;
     }
-
 }
 
 bool UDPServer::start()
@@ -80,7 +83,6 @@ bool UDPServer::start()
     {
         //qDebug() << "UDPServer::start: calling startNow " << QT_ENDL;
         return startNow(port, groupAddress);
-
     }
     else
     {
@@ -123,7 +125,6 @@ bool UDPServer::startNow(quint16 _port, QHostAddress const& _multicast_group_add
     }
     //qDebug() << "UDPServer::startNow exiting... "<< QT_ENDL;
     return  socketServer->isValid();
-
 }
 
 void UDPServer::joinMultiCastGroup()
@@ -245,7 +246,6 @@ void UDPServer::parse(const QByteArray &msg)
     QByteArray message;
     bool lowConfidence = false;
 
-
     qint32 rx_df = -1;  // Delta frequency
     qint32 tx_df = -1;  // Delta time
     QByteArray de_call;
@@ -258,9 +258,6 @@ void UDPServer::parse(const QByteArray &msg)
     quint32 TRPeriod;
     QByteArray confName;
 
-
-    //QByteArray msgOut;
-
     QDataStream in(msg);
     //QDataStream out(msgOut, QIODevice::ReadWrite);
     in.setVersion(16);
@@ -284,8 +281,7 @@ void UDPServer::parse(const QByteArray &msg)
     }
 
     //qDebug() << "UDPServer::parse: TYPE: " << QString::number(type)<< QT_ENDL;
-    //QDateTime dateTime, dateTimeOff;
-    //QString line;
+
     switch (type)
     {
         case Heartbeat:
@@ -296,7 +292,6 @@ void UDPServer::parse(const QByteArray &msg)
             // unpack message
             //in >> ch;
 
-
             if (realtime)
             {
                 in >> frequency >> mode >> dx_call >> report >> tx_mode >> tx_enabled >> transmitting >> decoding
@@ -352,7 +347,7 @@ void UDPServer::parse(const QByteArray &msg)
         break;
         case Clear:
             //qDebug() << "UDPServer::parse: -   type = " << QString::number(type) << " - OUT - Clear" << QT_ENDL;
-            emit clearSignal();
+            emit clearSignal(Q_FUNC_INFO);
         break;
         case Reply:
             //qDebug() << "UDPServer::parse: -   type = " << QString::number(type) << " - IN - Replay " << QT_ENDL;
@@ -463,13 +458,8 @@ void UDPServer::parse(const QByteArray &msg)
         default: //NO
                //qDebug() << "UDPServer::parse: -   type = " << QString::number(type) << " - ERROR on Type" << QT_ENDL;
         break;
-
     }
-
-
-
        //qDebug() << "UDPServer::parse: - Magic: = " << QString::number(magic)<< QT_ENDL;
-
 }
 
 
@@ -515,7 +505,6 @@ void UDPServer::setNetworkInterface(const QString &_t)
                 networkInterface = i;
                 haveNetworkInterface = true;
             }
-
         }
     }
 }
@@ -552,8 +541,6 @@ void UDPServer::setRealTimeUpdate(const bool _t)
 void UDPServer::adifParse(QByteArray &msg)
 {
     //qDebug() << "UDPServer::adifParse: " << msg <<  QT_ENDL;
-
-
     QString dx_call = QString();
     QString mode = QString();
     QString band = QString();
@@ -706,7 +693,6 @@ void UDPServer::adifParse(QByteArray &msg)
                 emit logged_qso (dx_call, mode, band, freq,
                                  mygrid, dxgrid, rstTX, rstRX, _comment, stationcallsign, _name,
                                  operatorCall, datetime, datetime_off, _exchangeTX, _exchangeRX, _myPWR);
-
                 return;
             }
             else
