@@ -28,8 +28,13 @@
 
 UpdateSatsData::UpdateSatsData(DataProxy_SQLite *dp, QObject *parent) : QObject(parent)
 {
-    util = new Utilities;
-     dataProxy = dp;
+    util = new Utilities(Q_FUNC_INFO);
+    dataProxy = dp;
+}
+
+UpdateSatsData::~UpdateSatsData()
+{
+    delete(util);
 }
 
 bool UpdateSatsData::satDataFileRead(const QString& tfileName)
