@@ -28,25 +28,33 @@
 /*
     This class implements general use utilities that can be used from any other class
     Anything that is not directly related with a class itself and could be used from different
-    classes should be here
+    classes should be here.
+
+    This classs hould not need to query the DB neither the DataProxy Class
 
 */
+#include <QObject>
 #include <QtGlobal>
 #include <QString>
 #include <QtWidgets>
 #include <QPalette>
-#include "locator.h"
 #include <QtDebug>
+#include "locator.h"
 #include "klogdefinitions.h"
+//#include "dataproxy_sqlite.h"
+
+class Utilities : public QObject {
+    Q_OBJECT
+    friend class tst_Utilities;
 
-class Utilities
-{
 public:
-    Utilities();
+    Utilities(const QString &_parentName);
     ~Utilities();
     void setDarkMode(const QString &_dm);
     bool isDarkMode();
     void setCallValidation(const bool _b);
+    void setLongPrefixes (const QStringList &_p);
+    void setSpecialCalls (const QStringList &_p);
 
     int getProgresStepForDialog(int totalSteps);
     bool trueOrFalse(const QString &_s); // reads a String and return true if s.upper()== TRUE :-)
@@ -60,6 +68,7 @@ public:
     void printQString(const QStringList &_qs);
     QString getKLogDBFile();
     QString getKLogDBBackupFile();
+    bool QStringToBool(const QString &_s);
 
     //QString getKLogDatabaseFile(const QString &_file);
     bool isDBFileExisting();
@@ -110,10 +119,15 @@ public:
     bool isValidDateFromString(const QString &_s);
     bool isValidDateTimeFromString(const QString &_s);
     bool isValidDXCC(const int _d);
+    bool isValidAntPath(const QString &_s);
+    bool isValidARRLSect(const QString &_s);
+    bool isValidContinent(const QString &_s);
     QStringList getValidADIFFieldAndData(const QString &_b);
+
+    QString getMainCallFromComplexCall(const QString &_complexCall); // F from F/EA4K/p, EA4K from EA4K/p or EA4K from EA4K
     QString getAValidCall (const QString &_wrongCall);
-    QString getPrefixFromCall(const QString &_c);
-    //QString getPrefixFromFullCall(const QString &_c);
+    QString getPrefixFromCall(const QString &_c, bool withAreaNumber = false);
+    bool isAOneLetterPrefix(const QChar &_c);
 
     // Write DATE/TIME to DB
     QString getDateTimeSQLiteStringFromDateTime(const QDateTime &_d);
@@ -144,21 +158,47 @@ public:
     QString getCabrilloTimeFromQDateTime(const QDateTime &_d);  // Will produce the Cabrillo TIME format: "HHMM"
 
     QString getOnlineServiceName(OnLineProvider _service);
+
+    bool isValidDistance(const double _d);
+    bool isValidSponsor(const QString &_s);
+
+    QString debugLevelToString(DebugLogLevel _l);
+    DebugLogLevel stringToDebugLevel(const QString &_s);
+    bool isValidLogLevel(const QString &_s);
+    QStringList getDebugLevels();
+    void setLogLevel(DebugLogLevel _l);
     //QPalette getPalete(bool _ok);
+signals:
+    void debugLog (QString _func, QString _msg, DebugLogLevel _level);
+
 private:
     void init();
+    void setLogColumnNames(); // Creates the map of column Names (should be called from init() )
     bool processConfigLine(const QString &_line);
     QString getKLogDefaultDatabaseFile();
-    bool isCountrySuffix (const QString &_c);
-    int isAPrefix(const QString &_c);
-    bool isValidSubCall(const QString &_c);
+    //bool isCountrySuffix (const QString &_c);
+    bool isAValidOperatingSuffix (const QString &_c);
+    bool isAPrefix(const QString &_c); // Returns true if it is the country prefix or it includes the area number
+    bool isAKnownPrefix(const QString &_c);
+    bool isAKnownCall(const QString &_c);
+    bool isValidSimpleCall(const QString &_c);
     //QPair<QString, QString> getCallParts(const QString &_c);
 
+    void setARRLSect();
+    void setContinent();
+    void setSponsorsList();
+    QString getCheckedComplexCall(const QString &_c);
+    void logEvent(const QString &_func, const QString &_msg, DebugLogLevel _level);
     bool darkMode;
     QString dbPath;
     QString softwareVersion;
-    //QPalette palRed, palBlack;
+    QString parentName;     // The class that instanciated this object.
 
+    QStringList ARRL_sects, continent, sponsorsList, logLevels;
+    DebugLogLevel logLevel;
+    QStringList longPrefixes, specialCalls;
+    QMap<QString, QString> columnNames;
+    bool validateCalls;
 };
 
 #endif // UTILITIES_H
