@@ -34,8 +34,9 @@ AdifLoTWExportWidget::AdifLoTWExportWidget(DataProxy_SQLite *dp, const QString &
 #endif
 
     dataProxy = dp;
-    util = new Utilities;
+    util = new Utilities(Q_FUNC_INFO);
     stationCallsignComboBox = new QComboBox;
+    myGridSquareComboBox = new QComboBox;
     startDate = new QDateEdit;
     endDate = new QDateEdit;
     okButton = new QPushButton;
@@ -45,7 +46,8 @@ AdifLoTWExportWidget::AdifLoTWExportWidget(DataProxy_SQLite *dp, const QString &
     numberLabel = new QLabel;
     selectedEMode = ModeLotW;   //By default this widget will be used for LoTW Export.
     defaultStationCallsign = QString();
-
+    util->setLongPrefixes(dataProxy->getLongPrefixes());
+    util->setSpecialCalls(dataProxy->getSpecialCallsigns());
     createUI();
 }
 AdifLoTWExportWidget::~AdifLoTWExportWidget()
@@ -64,6 +66,7 @@ void AdifLoTWExportWidget::setDefaultStationCallsign(const QString &_st)
 void AdifLoTWExportWidget::createUI()
 {
     //fillStationCallsignComboBox();
+    tableWidget->setSortingEnabled (true);
     stationCallsignComboBox->setToolTip(tr("Select the Station Callsign that you want to use to upload the log."));
 
     startDate->clear();
@@ -78,6 +81,9 @@ void AdifLoTWExportWidget::createUI()
     QLabel *stationLabel = new QLabel;
     stationLabel->setText(tr("Station callsign"));
 
+    QLabel *myGridLabel = new QLabel;
+    myGridLabel->setText(tr("My Locator"));
+
     QLabel *startLabel = new QLabel;
     startLabel->setText(tr("Start date"));
 
@@ -99,14 +105,20 @@ void AdifLoTWExportWidget::createUI()
     tableWidget->setColumnCount(header.length());
     tableWidget->setHorizontalHeaderLabels(header);
 
+
+
     QGridLayout *mainLayout = new QGridLayout;
     mainLayout->addWidget(topLabel, 0, 0, 1, -1);
     mainLayout->addWidget(stationLabel, 1, 0);
     mainLayout->addWidget(stationCallsignComboBox, 2, 0);
-    mainLayout->addWidget(startLabel, 1, 1);
-    mainLayout->addWidget(startDate, 2, 1);
-    mainLayout->addWidget(endLabel, 1, 2);
-    mainLayout->addWidget(endDate, 2, 2);
+
+    mainLayout->addWidget(myGridLabel, 1, 1);
+    mainLayout->addWidget(myGridSquareComboBox, 2, 1);
+
+    mainLayout->addWidget(startLabel, 1, 2);
+    mainLayout->addWidget(startDate, 2, 2);
+    mainLayout->addWidget(endLabel, 1, 3);
+    mainLayout->addWidget(endDate, 2, 3);
     mainLayout->addWidget(tableWidget, 3, 0, 1, -1);
     mainLayout->addWidget(numberLabel, 4, 0);
     mainLayout->addWidget(okButton, 4, 1);
@@ -116,10 +128,12 @@ void AdifLoTWExportWidget::createUI()
     connect(startDate, SIGNAL(dateChanged(QDate)), this, SLOT(slotDateChanged())) ;
     connect(endDate, SIGNAL(dateChanged(QDate)), this, SLOT(slotDateChanged() ));
     connect(stationCallsignComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(slotStationCallsignChanged() ) ) ;
+    connect(myGridSquareComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(slotMyGridChanged() ) ) ;
     connect(okButton, SIGNAL(clicked()), this, SLOT(slotOKPushButtonClicked() ) );
     connect(cancelButton, SIGNAL(clicked()), this, SLOT(slotCancelPushButtonClicked() ) );
 }
 
+
 void AdifLoTWExportWidget::setDefaultStationComboBox()
 {
     if (!util->isValidCall(defaultStationCallsign))
@@ -146,11 +160,37 @@ void AdifLoTWExportWidget::fillStationCallsignComboBox()
         stationCallsignComboBox->addItem(tr("All"));
          //qDebug() << "AdifLoTWExportWidget::fillStationCallsignComboBox-4" << QT_ENDL;
     }
-    //qDebug() << "AdifLoTWExportWidget::fillStationCallsignComboBox-99" << QT_ENDL;
-    stationCallsignComboBox->addItems(dataProxy->getStationCallSignsFromLog(logNumber));
+
+    //qDebug() << "AdifLoTWExportWidget::fillStationCallsignComboBox-99" << QString::number(currentExportMode);
+    stationCallsignComboBox->addItems(dataProxy->getStationCallSignsFromLogWithLoTWPendingToSend(logNumber));
     //qDebug() << "AdifLoTWExportWidget::fillStationCallsignComboBox-END" << QT_ENDL;
 }
 
+void AdifLoTWExportWidget::fillStationMyGridComboBox()
+{
+    //qDebug() << Q_FUNC_INFO << " - Start";
+    // Keep the grid that is shown now
+    // clean and fill the combo.
+    // If the saved locator is in the list, it is selected.
+
+    QString tempGrid = myGridSquareComboBox->currentText ();
+    myGridSquareComboBox->clear();
+    myGridSquareComboBox->addItem(tr("Not defined"));
+
+    QStringList grids;
+    grids.clear ();
+    grids.append (dataProxy->getGridsToBeSent (stationCallsignComboBox->currentText(), startDate->date(), endDate->date(), true, logNumber));
+    myGridSquareComboBox->addItems(grids);
+
+
+    if (myGridSquareComboBox->findText(tempGrid, Qt::MatchCaseSensitive) >= 0)
+    {
+       myGridSquareComboBox->setCurrentIndex(myGridSquareComboBox->findText(tempGrid, Qt::MatchCaseSensitive));
+    }
+
+    //qDebug() << Q_FUNC_INFO << " - END";
+}
+
 void AdifLoTWExportWidget::setTopLabel(const QString &_t)
 {
     topLabel->setText(_t);
@@ -159,6 +199,7 @@ void AdifLoTWExportWidget::setTopLabel(const QString &_t)
 void AdifLoTWExportWidget::fillTable()
 {
     //qDebug() << "AdifLoTWExportWidget::fillTable " << QT_ENDL;
+
     QList<int> qsos;
        qsos.clear();
        bool justQueued = true;
@@ -192,12 +233,12 @@ void AdifLoTWExportWidget::fillTable()
        if (stationCallsignComboBox->currentIndex() == 0)
        { // Not defined station_callsign (blank)
            //qDebug() << "AdifLoTWExportWidget::fillTable blank station callsign " << QT_ENDL;
-           qsos.append(dataProxy->getQSOsListLoTWToSend(QString(), startDate->date(), endDate->date(), justQueued, logNumber));
+           qsos.append(dataProxy->getQSOsListLoTWToSend(QString(), myGridSquareComboBox->currentText(), startDate->date(), endDate->date(), justQueued, logNumber));
        }
        else if((stationCallsignComboBox->currentIndex() == 1) && (currentExportMode == ModeADIF))
        { // ALL stations, no matter the station.
            //qDebug() << "AdifLoTWExportWidget::fillTable ALL station callsign " << QT_ENDL;
-           qsos.append(dataProxy->getQSOsListLoTWToSend("ALL", startDate->date(), endDate->date(), justQueued, logNumber));
+           qsos.append(dataProxy->getQSOsListLoTWToSend("ALL", myGridSquareComboBox->currentText (), startDate->date(), endDate->date(), justQueued, logNumber));
        }
        else
        {
@@ -220,7 +261,7 @@ void AdifLoTWExportWidget::fillTable()
            else if (currentExportMode == ModeLotW)
            {
                //qDebug() << "AdifLoTWExportWidget::fillTable Mode QRZ" << QT_ENDL;
-                qsos.append(dataProxy->getQSOsListLoTWToSend (stationCallsignComboBox->currentText(), startDate->date(), endDate->date(), true, logNumber));
+                qsos.append(dataProxy->getQSOsListLoTWToSend (stationCallsignComboBox->currentText(), myGridSquareComboBox->currentText (), startDate->date(), endDate->date(), true, logNumber));
               //qsos.append(dataProxy->getQSOsListQRZCOMToSent(stationCallsignComboBox->currentText(), startDate->date(), endDate->date(), true));
            }
            else
@@ -300,14 +341,23 @@ void AdifLoTWExportWidget::slotStationCallsignChanged()
     //qDebug() << "AdifLoTWExportWidget::slotStationCallsignChanged-02"  << QT_ENDL;
     endDate->setDate(dataProxy->getLastQSODateFromCall(stationCallsignComboBox->currentText()));
     //qDebug() << "AdifLoTWExportWidget::slotStationCallsignChanged-03"  << QT_ENDL;
-    fillTable();
+    fillStationMyGridComboBox();
+    fillTable ();
+
     //qDebug() << "AdifLoTWExportWidget::slotStationCallsignChanged - END" << QT_ENDL;
 }
 
+
+void AdifLoTWExportWidget::slotMyGridChanged()
+{
+    fillTable();
+}
+
+
 void AdifLoTWExportWidget::slotDateChanged()
 {
     //slotStationCallsignChanged();
-    fillTable();
+    slotStationCallsignChanged ();
 }
 
 void AdifLoTWExportWidget::slotOKPushButtonClicked()
