@@ -30,18 +30,22 @@
 ShowAdifImportWidget::ShowAdifImportWidget(DataProxy_SQLite *dp, const QString &_parentFunction, QWidget *parent) : QWidget(parent)
 {
     dataProxy = dp;
-    util = new Utilities;
+    util = new Utilities(Q_FUNC_INFO);
     okButton = new QPushButton;
     //cancelButton = new QPushButton;
     tableWidget = new QTableWidget;
     qsosList.clear();
     setWindowTitle("ShowAdif");
     createUI();
+    util->setLongPrefixes(dataProxy->getLongPrefixes());
+    util->setSpecialCalls(dataProxy->getSpecialCallsigns());
 }
+
 ShowAdifImportWidget::~ShowAdifImportWidget()
 {
     delete(util);
 }
+
 void ShowAdifImportWidget::createUI()
 {
     QLabel *msgLabel = new QLabel;
