@@ -30,7 +30,7 @@
 #include <QString>
 #include <QFile>
 #include <QStringList>
-#include <QSqlRelationalTableModel>
+//#include <QSqlRelationalTableModel>
 #include <QSqlQuery>
 #include <QSqlError>
 #include <QProgressBar>
@@ -40,6 +40,7 @@
 
 #include "locator.h"
 #include "dataproxy_sqlite.h"
+#include "utilities.h"
 //#include "klogdefinitions.h"
 //#include "awards.h"
 
@@ -52,19 +53,20 @@ enum
     Entity_Continent = 2
 };
 
-class World : public QWidget
+class World : public QObject
 {
     //friend class Awards;
     Q_OBJECT
 
 public:
     World(DataProxy_SQLite *dp, const QString &_parentFunction);
-    World(DataProxy_SQLite *dp, const QString &_klogDir, const QString &_parentFunction);
-    World(DataProxy_SQLite *dp, const QString &_klogDir, const QString &_klogVer, const QString &_parentFunction);
+    //World(DataProxy_SQLite *dp, const QString &_klogDir, const QString &_parentFunction);
+    //World(DataProxy_SQLite *dp, const QString &_klogVer, const QString &_parentFunction);
 
     ~World();
     bool create(const QString &_worldFile);
     bool recreate(const QString &_worldFile);
+    bool readWorld();
 
     QString getQRZEntityName(const QString &_qrz);
     QString getEntityName(const int _entityN);
@@ -98,13 +100,9 @@ public:
     bool isNewCQz(const int _cqz);
     bool isNewEntity(const int _entityN);
     //int getBandIdFromFreq(const QString fr);
-
-    QString getQRZEntityPrefixes(const QString &_qrz);
     QString getEntityPrefixes(const int _enti);
 
-    bool checkQRZValidFormat(const QString &_qrz);
-
-    QStringList getEntitiesNames();
+    //QStringList getEntitiesNames();
     int getHowManyEntities();
     bool hasSpecialEntities();
 
@@ -114,19 +112,18 @@ private slots:
 private:
     //void identifyOS();
     bool insertSpecialEntities();
-    int getPrefixId(const QString &_qrz);
+    int getPrefixId(const QString &_prefix);
     //bool readCTYDAT();
     bool readCTYCSV(const QString &_worldFile);
     QStringList processLine(const QString &_line);
     QStringList processLineP(const QString &_line, const int _processingEntity);
-    void createWorldModel();
+    //void createWorldModel();
     QStringList readZones(const QString &pref, const int _cq, const int _itu);
-    QString changeSlashAndFindPrefix(const QString &_qrz); // Changes the \ into / and find the country prefix
 
     int progressBarPosition;
 
     bool created;
-    QString klogDir, klogVersion;
+    //QString klogVersion;
     int cqz, ituz, numberOfEntities;
     QString entityName;
     QString currentPrefix; // Used in the progressBar
@@ -141,14 +138,12 @@ private:
     //bool readingDataOfAnEntity;
     int nullValue;
 
-
-    QSqlRelationalTableModel *worldModel;
-    //QProgressBar *progressBar;
-
     Locator *locator;
     DataProxy_SQLite *dataProxy;
+    Utilities *util;
+    QHash<QString, int> worldPrefixes;
 
-    int constrid; // Just an id for the constructor to check who is being executed at one specific time
+    //int constrid; // Just an id for the constructor to check who is being executed at one specific time
     //Awards *awards;
     //FLAGS
     //QString flagsDir;
